@@ -67,16 +67,12 @@ osx-package)
   mvn -e package
   ;;
 
-osx-jdk12-package)
-  exclude1="!FileContentsTest#testGetJavadocBefore,"
-  exclude2="!MainFrameModelPowerTest#testOpenFileWithUnknownParseMode,"
-  exclude3="!TokenUtilTest#testTokenValueIncorrect2,"
-  exclude4="!ImportControlLoaderPowerTest#testInputStreamThatFailsOnClose"
+osx-jdk13-package)
   export JAVA_HOME=$(/usr/libexec/java_home)
-  mvn -e package -Dtest=*,${exclude1}${exclude2}${exclude3}${exclude4}
+  mvn -e package
   ;;
 
-osx-jdk12-assembly)
+osx-jdk13-assembly)
   mvn -e package -Passembly
   ;;
 
@@ -84,10 +80,6 @@ site)
   mvn -e clean site -Pno-validations
   ;;
 
-javac9)
-  javac $(grep -Rl --include='*.java' ': Compilable with Java9' src/test/resources-noncompilable)
-  ;;
-
 javac8)
   # InputCustomImportOrderNoPackage2 - nothing is required in front of first import
   # InputIllegalTypePackageClassName - bad import for testing
@@ -105,12 +97,40 @@ javac8)
   done
   ;;
 
-jdk12-assembly-site)
+javac9)
+  files=($(grep -Rl --include='*.java' ': Compilable with Java9' \
+        src/test/resources-noncompilable || true))
+  if [[  ${#files[@]} -eq 0 ]]; then
+    echo "No Java9 files to process"
+  else
+      mkdir -p target
+      for file in "${files[@]}"
+      do
+        javac --release 9 -d target "${file}"
+      done
+  fi
+  ;;
+
+javac13)
+  files=($(grep -Rl --include='*.java' ': Compilable with Java13' \
+        src/test/resources-noncompilable || true))
+  if [[  ${#files[@]} -eq 0 ]]; then
+    echo "No Java13 files to process"
+  else
+      mkdir -p target
+      for file in "${files[@]}"
+      do
+        javac --release 13 --enable-preview -d target "${file}"
+      done
+  fi
+  ;;
+
+jdk13-assembly-site)
   mvn -e package -Passembly
   mvn -e site -Pno-validations
   ;;
 
-jdk12-verify-limited)
+jdk13-verify-limited)
   # we skip pmd and spotbugs as they executed in special Travis build
   mvn -e verify -Dpmd.skip=true -Dspotbugs.skip=true
   ;;
@@ -157,22 +177,6 @@ assembly-run-all-jar)
   if grep 'warning' output.log ; then exit 1; fi
   ;;
 
-sonarqube)
-  # token could be generated at https://sonarcloud.io/account/security/
-  # executon on local: SONAR_TOKEN=xxxxxxxxxx ./.ci/travis/travis.sh sonarqube
-  if [ -v TRAVIS_PULL_REQUEST ] && [[ $TRAVIS_PULL_REQUEST && $TRAVIS_PULL_REQUEST =~ ^([0-9]*)$ ]];
-    then
-      exit 0;
-  fi
-  if [[ -z $SONAR_TOKEN ]]; then echo "SONAR_TOKEN is not set"; sleep 5s; exit 1; fi
-  export MAVEN_OPTS='-Xmx2000m'
-  mvn -e clean package sonar:sonar \
-       -Dsonar.host.url=https://sonarcloud.io \
-       -Dsonar.login=$SONAR_TOKEN \
-       -Dmaven.test.failure.ignore=true \
-       -Dcheckstyle.skip=true -Dpmd.skip=true -Dcheckstyle.ant.skip=true
-  ;;
-
 release-dry-run)
   if [ $(git log -1 | grep -E "\[maven-release-plugin\] prepare release" | cat | wc -l) -lt 1 ];then
     mvn -e release:prepare -DdryRun=true --batch-mode -Darguments='-DskipTests -DskipITs \
@@ -250,14 +254,16 @@ no-exception-test-checkstyle-sevntu-checkstyle)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                     --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: $CS_POM_VERSION
+  mkdir -p .ci-temp/
+  cd .ci-temp/
   git clone https://github.com/checkstyle/contribution
   cd contribution/checkstyle-tester
   sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
   sed -i.'' 's/#checkstyle/checkstyle/' projects-to-test-on.properties
   sed -i.'' 's/#sevntu-checkstyle/sevntu-checkstyle/' projects-to-test-on.properties
-  cd ../../
+  cd ../../../
   mvn -e clean install -Pno-validations
-  cd contribution/checkstyle-tester
+  cd .ci-temp/contribution/checkstyle-tester
   export MAVEN_OPTS="-Xmx2048m"
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
     --config checks-nonjavadoc-error.xml --checkstyleVersion $CS_POM_VERSION
@@ -267,13 +273,15 @@ no-exception-test-guava)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                     --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: $CS_POM_VERSION
+  mkdir -p .ci-temp/
+  cd .ci-temp/
   git clone https://github.com/checkstyle/contribution
   cd contribution/checkstyle-tester
   sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
   sed -i.'' 's/#guava|/guava|/' projects-to-test-on.properties
-  cd ../../
+  cd ../../../
   mvn -e clean install -Pno-validations
-  cd contribution/checkstyle-tester
+  cd .ci-temp/contribution/checkstyle-tester
   export MAVEN_OPTS="-Xmx2048m"
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties
      --config checks-nonjavadoc-error.xml --checkstyleVersion $CS_POM_VERSION
@@ -283,47 +291,55 @@ no-exception-test-guava-with-google-checks)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: $CS_POM_VERSION
+  mkdir -p .ci-temp/
+  cd .ci-temp/
   git clone https://github.com/checkstyle/contribution
   cd contribution/checkstyle-tester
   sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
   sed -i.'' 's/#guava|/guava|/' projects-to-test-on.properties
-  cd ../../
+  cd ../../../
   mvn -e clean install -Pno-validations
-  sed -i.'' 's/warning/ignore/' src/main/resources/google_checks.xml
-  cd contribution/checkstyle-tester
+  cp src/main/resources/google_checks.xml .ci-temp/google_checks.xml
+  sed -i.'' 's/warning/ignore/' .ci-temp/google_checks.xml
+  cd .ci-temp/contribution/checkstyle-tester
   export MAVEN_OPTS="-Xmx2048m"
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
-      --config ../../src/main/resources/google_checks.xml --checkstyleVersion $CS_POM_VERSION
+      --config ../../google_checks.xml --checkstyleVersion $CS_POM_VERSION
   ;;
 
 no-exception-test-guava-with-sun-checks)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: $CS_POM_VERSION
+  mkdir -p .ci-temp/
+  cd .ci-temp/
   git clone https://github.com/checkstyle/contribution
   cd contribution/checkstyle-tester
   sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
   sed -i.'' 's/#guava|/guava|/' projects-to-test-on.properties
-  cd ../../
+  cd ../../../
   mvn -e clean install -Pno-validations
-  sed -i.'' 's/value=\"error\"/value=\"ignore\"/' src/main/resources/sun_checks.xml
-  cd contribution/checkstyle-tester
+  cp src/main/resources/sun_checks.xml .ci-temp/sun_checks.xml
+  sed -i.'' 's/value=\"error\"/value=\"ignore\"/' .ci-temp/sun_checks.xml
+  cd .ci-temp/contribution/checkstyle-tester
   export MAVEN_OPTS="-Xmx2048m"
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
-      --config ../../src/main/resources/sun_checks.xml --checkstyleVersion $CS_POM_VERSION
+      --config ../../sun_checks.xml --checkstyleVersion $CS_POM_VERSION
   ;;
 
 no-exception-test-hibernate)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                     --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: $CS_POM_VERSION
+  mkdir -p .ci-temp/
+  cd .ci-temp/
   git clone https://github.com/checkstyle/contribution
   cd contribution/checkstyle-tester
   sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
   sed -i.'' 's/#hibernate-orm/hibernate-orm/' projects-to-test-on.properties
-  cd ../../
+  cd ../../../
   mvn -e clean install -Pno-validations
-  cd contribution/checkstyle-tester
+  cd .ci-temp/contribution/checkstyle-tester
   export MAVEN_OPTS="-Xmx2048m"
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
      --config checks-nonjavadoc-error.xml --checkstyleVersion $CS_POM_VERSION
@@ -333,13 +349,15 @@ no-exception-test-spotbugs)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: $CS_POM_VERSION
+  mkdir -p .ci-temp/
+  cd .ci-temp/
   git clone https://github.com/checkstyle/contribution
   cd contribution/checkstyle-tester
   sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
   sed -i.'' 's/#spotbugs/spotbugs/' projects-to-test-on.properties
-  cd ../../
+  cd ../../../
   mvn -e clean install -Pno-validations
-  cd contribution/checkstyle-tester
+  cd .ci-temp/contribution/checkstyle-tester
   export MAVEN_OPTS="-Xmx2048m"
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
     --config checks-nonjavadoc-error.xml --checkstyleVersion $CS_POM_VERSION
@@ -349,13 +367,15 @@ no-exception-test-spring-framework)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: $CS_POM_VERSION
+  mkdir -p .ci-temp/
+  cd .ci-temp/
   git clone https://github.com/checkstyle/contribution
   cd contribution/checkstyle-tester
   sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
   sed -i.'' 's/#spring-framework/spring-framework/' projects-to-test-on.properties
-  cd ../../
+  cd ../../../
   mvn -e clean install -Pno-validations
-  cd contribution/checkstyle-tester
+  cd .ci-temp/contribution/checkstyle-tester
   export MAVEN_OPTS="-Xmx2048m"
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
     --config checks-nonjavadoc-error.xml --checkstyleVersion $CS_POM_VERSION
@@ -365,13 +385,15 @@ no-exception-test-hbase)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: $CS_POM_VERSION
+  mkdir -p .ci-temp/
+  cd .ci-temp/
   git clone https://github.com/checkstyle/contribution
   cd contribution/checkstyle-tester
   sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
   sed -i.'' 's/#Hbase/Hbase/' projects-to-test-on.properties
-  cd ../../
+  cd ../../../
   mvn -e clean install -Pno-validations
-  cd contribution/checkstyle-tester
+  cd .ci-temp/contribution/checkstyle-tester
   export MAVEN_OPTS="-Xmx2048m"
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion $CS_POM_VERSION
@@ -381,15 +403,17 @@ no-exception-test-Pmd-elasticsearch-lombok-ast)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: $CS_POM_VERSION
+  mkdir -p .ci-temp/
+  cd .ci-temp/
   git clone https://github.com/checkstyle/contribution
   cd contribution/checkstyle-tester
   sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
   sed -i.'' 's/#pmd/pmd/' projects-to-test-on.properties
   sed -i.'' 's/#elasticsearch/elasticsearch/' projects-to-test-on.properties
   sed -i.'' 's/#lombok-ast/lombok-ast/' projects-to-test-on.properties
-  cd ../../
+  cd ../../../
   mvn -e clean install -Pno-validations
-  cd contribution/checkstyle-tester
+  cd .ci-temp/contribution/checkstyle-tester
   export MAVEN_OPTS="-Xmx2048m"
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion $CS_POM_VERSION
@@ -399,6 +423,8 @@ no-exception-test-alot-of-project1)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: $CS_POM_VERSION
+  mkdir -p .ci-temp/
+  cd .ci-temp/
   git clone https://github.com/checkstyle/contribution
   cd contribution/checkstyle-tester
   sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
@@ -408,9 +434,9 @@ no-exception-test-alot-of-project1)
   sed -i.'' 's/#apache-ant/apache-ant/' projects-to-test-on.properties
   sed -i.'' 's/#apache-jsecurity/apache-jsecurity/' projects-to-test-on.properties
   sed -i.'' 's/#android-launcher/android-launcher/' projects-to-test-on.properties
-  cd ../../
+  cd ../../../
   mvn -e clean install -Pno-validations
-  cd contribution/checkstyle-tester
+  cd .ci-temp/contribution/checkstyle-tester
   export MAVEN_OPTS="-Xmx2048m"
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion $CS_POM_VERSION
@@ -458,19 +484,53 @@ check-missing-pitests)
   ;;
 
 verify-no-exception-configs)
+  mkdir -p .ci-temp
   wget -q \
+    --directory-prefix .ci-temp \
+    --no-clobber \
     https://raw.githubusercontent.com/checkstyle/contribution/master/checkstyle-tester/checks-nonjavadoc-error.xml
   wget -q \
+    --directory-prefix .ci-temp \
+    --no-clobber \
     https://raw.githubusercontent.com/checkstyle/contribution/master/checkstyle-tester/checks-only-javadoc-error.xml
   MODULES_WITH_EXTERNAL_FILES="Filter|ImportControl"
   xmlstarlet sel --net --template -m .//module -v "@name" \
-    -n checks-nonjavadoc-error.xml -n checks-only-javadoc-error.xml \
+    -n .ci-temp/checks-nonjavadoc-error.xml -n .ci-temp/checks-only-javadoc-error.xml \
     | grep -vE $MODULES_WITH_EXTERNAL_FILES | grep -v "^$" \
-    | sort | uniq | sed "s/Check$//" > web.txt
+    | sort | uniq | sed "s/Check$//" > .ci-temp/web.txt
   xmlstarlet sel --net --template -m .//module -v "@name" -n config/checkstyle_checks.xml \
     | grep -vE $MODULES_WITH_EXTERNAL_FILES | grep -v "^$" \
-    | sort | uniq | sed "s/Check$//" > file.txt
-  diff -u web.txt file.txt
+    | sort | uniq | sed "s/Check$//" > .ci-temp/file.txt
+  DIFF_TEXT=$(diff -u .ci-temp/web.txt .ci-temp/file.txt | cat)
+  if [[ $DIFF_TEXT != "" ]]; then
+    echo "Diff is detected."
+    if [[ $TRAVIS_PULL_REQUEST =~ ^([0-9]+)$ ]]; then
+      LINK_PR=https://api.github.com/repos/checkstyle/checkstyle/pulls/$TRAVIS_PULL_REQUEST
+      REGEXP="https://github.com/checkstyle/contribution/pull/"
+      PR_DESC=$(curl -s -H "Authorization: token $READ_ONLY_TOKEN" $LINK_PR \
+                  | jq '.body' | grep $REGEXP | cat )
+      echo 'PR Description grepped:'${PR_DESC:0:180}
+      if [[ -z $PR_DESC ]]; then
+        echo 'You introduce new Check'
+        diff -u .ci-temp/web.txt .ci-temp/file.txt | cat
+        echo 'Please create PR to repository https://github.com/checkstyle/contribution'
+        echo 'and add your new Check '
+        echo '   to file checkstyle-tester/checks-nonjavadoc-error.xml'
+        echo 'or to file checkstyle-tester/checks-only-javadoc-error.xml'
+        echo 'PR for contribution repository will be merged right after this PR.'
+        sleep 5s
+        false;
+      fi
+    else
+      diff -u .ci-temp/web.txt .ci-temp/file.txt | cat
+      echo 'file config/checkstyle_checks.xml contains Check that is not present at:'
+      echo 'https://github.com/checkstyle/contribution/checkstyle-tester/checks-nonjavadoc-error.xml'
+      echo 'https://github.com/checkstyle/contribution/checkstyle-tester/checks-nonjavadoc-error.xml'
+      echo 'Please add new Check to one of such files to let Check participate in auto testing'
+      sleep 5s
+      false;
+    fi
+  fi
   ;;
 
 git-status)
@@ -481,6 +541,44 @@ git-status)
   fi
   ;;
 
+check-since-version)
+  ## Travis merges the PR commit into origin/master
+  ## This identifies the PR's original commit
+  ## if it notices a merge commit
+  HEAD=`git rev-parse HEAD`
+  if git show --summary HEAD | grep ^Merge: ; then
+      echo "Merge detected."
+      HEAD=`git log -n 1 --no-merges --pretty=format:"%H"`
+  fi
+  ## Identify previous commit to know how much to examine
+  ## Script assumes we are only working with 1 commit if we are in master
+  ## Otherwise, it looks for the common ancestor with master
+  COMMIT=`git rev-parse $HEAD`
+  echo "PR commit: $COMMIT"
+
+  HEAD_NEW_FILES=$(git show $COMMIT | cat | grep -A 1 "\-\-\- /dev/null" | cat)
+  echo "New files in commit: $HEAD_NEW_FILES"
+  MODULE_REG=".*(Check|Filter).java"
+  REGEXP="b/src/main/java/com/puppycrawl/tools/checkstyle/(checks|filters|filefilters)/$MODULE_REG"
+  NEW_CHECK_FILE=$(git show $COMMIT | cat | grep -A 1 "\-\-\- /dev/null" | cat | \
+    grep -E "$REGEXP" | \
+    cat | sed "s/+++ b\///")
+  echo "New Check file: $NEW_CHECK_FILE"
+
+  if [ -f "$NEW_CHECK_FILE" ]; then
+    echo "New Check detected: $NEW_CHECK_FILE"
+    CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
+                     --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
+    CS_RELEASE_VERSION=$(echo $CS_POM_VERSION | cut -d '-' -f 1)
+    echo "CS Release version: $CS_RELEASE_VERSION"
+    echo "Grep for @since $CS_RELEASE_VERSION"
+    sleep 5s
+    grep "* @since $CS_RELEASE_VERSION" $NEW_CHECK_FILE
+  else
+    echo "No new Check, all is good."
+  fi
+  ;;
+
 *)
   echo "Unexpected argument: $1"
   sleep 5s
