@@ -20,10 +20,11 @@ if [[ -z $PREV_RELEASE ]]; then
   exit 1
 fi
 
-echo "Version bump in pom.xml (release:prepare) ..."
 SKIP_TEST="-DskipTests -DskipITs"
 SKIP_CHECKSTYLE="-Dcheckstyle.ant.skip=true -Dcheckstyle.skip=true"
 SKIP_OTHERS="-Dpmd.skip=true -Dspotbugs.skip=true -Djacoco.skip=true -Dxml.skip=true"
+
+echo "Version bump in pom.xml (release:prepare) ..."
 mvn -e -Pgpg release:prepare -B -Darguments="$SKIP_TEST $SKIP_CHECKSTYLE $SKIP_OTHERS"
 
 echo "Deployment of jars to maven central (release:perform) ..."
@@ -32,6 +33,9 @@ mvn -e -Pgpg release:perform -Darguments="$SKIP_CHECKSTYLE"
 echo "Go to folder where site was build and sources are already at required tag"
 cd target/checkout
 
+echo "Generating web site"
+mvn -e site
+
 echo "Generating uber jar ...(no clean to keep site resources just in case)"
 mvn -e -Passembly package
 
