@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,7 @@ package com.google.checkstyle.test.chapter5naming.rule53camelcase;
 
 import java.io.IOException;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import com.google.checkstyle.test.base.AbstractGoogleModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.api.Configuration;
@@ -42,12 +42,12 @@ public class AbbreviationAsWordInNameTest extends AbstractGoogleModuleTestSuppor
         final int maxCapitalCount = 2;
 
         final String[] expected = {
-            "53: " + getWarningMessage("supportsIPv6OnIOS", maxCapitalCount),
-            "55: " + getWarningMessage("XMLHTTPRequest", maxCapitalCount),
-            "61: " + getWarningMessage("supportsIPv6OnIOS", maxCapitalCount),
-            "63: " + getWarningMessage("XMLHTTPRequest", maxCapitalCount),
-            "71: " + getWarningMessage("supportsIPv6OnIOS", maxCapitalCount),
-            "73: " + getWarningMessage("XMLHTTPRequest", maxCapitalCount),
+            "53:13: " + getWarningMessage("supportsIPv6OnIOS", maxCapitalCount),
+            "55:10: " + getWarningMessage("XMLHTTPRequest", maxCapitalCount),
+            "61:17: " + getWarningMessage("supportsIPv6OnIOS", maxCapitalCount),
+            "63:14: " + getWarningMessage("XMLHTTPRequest", maxCapitalCount),
+            "71:21: " + getWarningMessage("supportsIPv6OnIOS", maxCapitalCount),
+            "73:18: " + getWarningMessage("XMLHTTPRequest", maxCapitalCount),
         };
 
         final String filePath = getPath("InputAbbreviationAsWordInTypeNameCheck.java");
