@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,20 +19,23 @@
 
 package org.checkstyle.suppressionxpathfilter;
 
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
 import java.io.File;
+import java.io.IOException;
 import java.io.Writer;
 import java.nio.charset.StandardCharsets;
+import java.nio.file.DirectoryStream;
 import java.nio.file.Files;
+import java.nio.file.Path;
 import java.util.List;
 import java.util.Locale;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 import org.checkstyle.base.AbstractCheckstyleModuleTestSupport;
-import org.junit.Rule;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
 
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
 import com.puppycrawl.tools.checkstyle.JavaParser;
@@ -52,11 +55,50 @@ public abstract class AbstractXpathTestSupport extends AbstractCheckstyleModuleT
     private static final Pattern LINE_COLUMN_NUMBER_REGEX =
             Pattern.compile("([0-9]+):([0-9]+):");
 
-    @Rule
-    public final TemporaryFolder temporaryFolder = new TemporaryFolder();
+    /**
+     * <p>
+     * The temporary folder to hold intermediate files.
+     * </p>
+     * <p>
+     * Till https://github.com/junit-team/junit5/issues/1786
+     * we need to create and clean it manually.
+     * Once this issue will be resolved, it should be annotated with &#64;TempDir
+     * and methods setupTemporaryFolder and removeTemporaryFolder should be dropped.
+     * </p>
+     */
+    private Path temporaryFolder;
 
     protected abstract String getCheckName();
 
+    /**
+     * <p>
+     * Creates temporary folder for intermediate files.
+     * </p>
+     *
+     * @throws IOException if an IO error occurs
+     */
+    @BeforeEach
+    public void setupTemporaryFolder() throws IOException {
+        temporaryFolder = Files.createTempDirectory("xpath-test");
+    }
+
+    /**
+     * <p>
+     * Removes temporary folder with intermediate files.
+     * </p>
+     *
+     * @throws IOException if an IO error occurs
+     */
+    @AfterEach
+    public void removeTemporaryFolder() throws IOException {
+        try (DirectoryStream<Path> paths = Files.newDirectoryStream(temporaryFolder)) {
+            for (Path path : paths) {
+                Files.delete(path);
+            }
+        }
+        Files.delete(temporaryFolder);
+    }
+
     @Override
     protected String getPackageLocation() {
         final String subpackage = getCheckName().toLowerCase(Locale.ENGLISH)
@@ -80,16 +122,16 @@ public abstract class AbstractXpathTestSupport extends AbstractCheckstyleModuleT
 
     private static void verifyXpathQueries(List<String> generatedXpathQueries,
                                            List<String> expectedXpathQueries) {
-        assertEquals("Generated queries do not match expected ones", expectedXpathQueries,
-                generatedXpathQueries);
+        assertEquals(expectedXpathQueries,
+                generatedXpathQueries, "Generated queries do not match expected ones");
     }
 
     private String createSuppressionsXpathConfigFile(String checkName,
                                                      List<String> xpathQueries)
             throws Exception {
-
-        final File suppressionsXpathConfigFile = temporaryFolder.newFile();
-        try (Writer bw = Files.newBufferedWriter(suppressionsXpathConfigFile.toPath(),
+        final Path suppressionsXpathConfigPath =
+                Files.createTempFile(temporaryFolder, "", "");
+        try (Writer bw = Files.newBufferedWriter(suppressionsXpathConfigPath,
                 StandardCharsets.UTF_8)) {
             bw.write("<?xml version=\"1.0\"?>\n");
             bw.write("<!DOCTYPE suppressions PUBLIC\n");
@@ -108,7 +150,7 @@ public abstract class AbstractXpathTestSupport extends AbstractCheckstyleModuleT
             bw.write("</suppressions>");
         }
 
-        return suppressionsXpathConfigFile.getPath();
+        return suppressionsXpathConfigPath.toString();
     }
 
     private DefaultConfiguration createSuppressionXpathFilter(String checkName,
