@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2018 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -86,10 +86,6 @@ public class Checker extends AutomaticBean implements MessageDispatcher, RootMod
     /** The audit event filters. */
     private final FilterSet filters = new FilterSet();
 
-    /** Class loader to resolve classes with. **/
-    private ClassLoader classLoader = Thread.currentThread()
-            .getContextClassLoader();
-
     /** The basedir to strip off in file names. */
     private String basedir;
 
@@ -131,6 +127,9 @@ public class Checker extends AutomaticBean implements MessageDispatcher, RootMod
     /** Controls whether exceptions should halt execution or not. */
     private boolean haltOnException = true;
 
+    /** The tab width for column reporting. */
+    private int tabWidth = CommonUtil.DEFAULT_TAB_WIDTH;
+
     /**
      * Creates a new {@code Checker} instance.
      * The instance needs to be contextualized and configured.
@@ -271,12 +270,15 @@ public class Checker extends AutomaticBean implements MessageDispatcher, RootMod
      * Processes a list of files with all FileSetChecks.
      * @param files a list of files to process.
      * @throws CheckstyleException if error condition within Checkstyle occurs.
+     * @throws Error wraps any java.lang.Error happened during execution
      * @noinspection ProhibitedExceptionThrown
      */
+    //-@cs[CyclomaticComplexity] no easy way to split this logic of processing the file
     private void processFiles(List<File> files) throws CheckstyleException {
         for (final File file : files) {
+            String fileName = null;
             try {
-                final String fileName = file.getAbsolutePath();
+                fileName = file.getAbsolutePath();
                 final long timestamp = file.lastModified();
                 if (cacheFile != null && cacheFile.isInCache(fileName, timestamp)
                         || !acceptFileStarted(fileName)) {
@@ -293,11 +295,19 @@ public class Checker extends AutomaticBean implements MessageDispatcher, RootMod
             // -@cs[IllegalCatch] There is no other way to deliver filename that was under
             // processing. See https://github.com/checkstyle/checkstyle/issues/2285
             catch (Exception ex) {
+                if (fileName != null && cacheFile != null) {
+                    cacheFile.remove(fileName);
+                }
+
                 // We need to catch all exceptions to put a reason failure (file name) in exception
                 throw new CheckstyleException("Exception was thrown while processing "
                         + file.getPath(), ex);
             }
             catch (Error error) {
+                if (fileName != null && cacheFile != null) {
+                    cacheFile.remove(fileName);
+                }
+
                 // We need to catch all errors to put a reason failure (file name) in error
                 throw new Error("Error was thrown while processing " + file.getPath(), error);
             }
@@ -432,10 +442,10 @@ public class Checker extends AutomaticBean implements MessageDispatcher, RootMod
 
         final DefaultContext context = new DefaultContext();
         context.add("charset", charset);
-        context.add("classLoader", classLoader);
         context.add("moduleFactory", moduleFactory);
         context.add("severity", severity.getName());
         context.add("basedir", basedir);
+        context.add("tabWidth", String.valueOf(tabWidth));
         childContext = context;
     }
 
@@ -582,9 +592,12 @@ public class Checker extends AutomaticBean implements MessageDispatcher, RootMod
      * quality of their reports, e.g. to load a class and then analyze it via
      * reflection.
      * @param classLoader the new classloader
+     * @deprecated Checkstyle is not type aware tool and all class loading is potentially
+     *     unstable.
      */
+    @Deprecated
     public final void setClassLoader(ClassLoader classLoader) {
-        this.classLoader = classLoader;
+        // no code
     }
 
     @Override
@@ -614,6 +627,14 @@ public class Checker extends AutomaticBean implements MessageDispatcher, RootMod
         this.haltOnException = haltOnException;
     }
 
+    /**
+     * Set the tab width to report audit events with.
+     * @param tabWidth an {@code int} value
+     */
+    public final void setTabWidth(int tabWidth) {
+        this.tabWidth = tabWidth;
+    }
+
     /**
      * Clears the cache.
      */
