@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2018 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -42,7 +42,6 @@ import org.antlr.v4.runtime.misc.ParseCancellationException;
 import org.antlr.v4.runtime.tree.ParseTree;
 import org.antlr.v4.runtime.tree.TerminalNode;
 
-import com.google.common.base.CaseFormat;
 import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.DetailNode;
 import com.puppycrawl.tools.checkstyle.api.JavadocTokenTypes;
@@ -202,8 +201,7 @@ public class JavadocDetailNodeParser {
         while (currentJavadocParent != null) {
             // remove unnecessary children tokens
             if (currentJavadocParent.getType() == JavadocTokenTypes.TEXT) {
-                currentJavadocParent
-                        .setChildren((DetailNode[]) JavadocNodeImpl.EMPTY_DETAIL_NODE_ARRAY);
+                currentJavadocParent.setChildren(JavadocNodeImpl.EMPTY_DETAIL_NODE_ARRAY);
             }
 
             final JavadocNodeImpl[] children =
@@ -221,21 +219,20 @@ public class JavadocDetailNodeParser {
 
                 ParseTree nextParseTreeSibling = getNextSibling(parseTreeParent);
 
-                if (nextJavadocSibling == null) {
-                    JavadocNodeImpl tempJavadocParent =
+                while (nextJavadocSibling == null) {
+                    currentJavadocParent =
                             (JavadocNodeImpl) currentJavadocParent.getParent();
 
-                    ParseTree tempParseTreeParent = parseTreeParent.getParent();
+                    parseTreeParent = parseTreeParent.getParent();
 
-                    while (nextJavadocSibling == null && tempJavadocParent != null) {
-                        nextJavadocSibling = (JavadocNodeImpl) JavadocUtil
-                                .getNextSibling(tempJavadocParent);
-
-                        nextParseTreeSibling = getNextSibling(tempParseTreeParent);
-
-                        tempJavadocParent = (JavadocNodeImpl) tempJavadocParent.getParent();
-                        tempParseTreeParent = tempParseTreeParent.getParent();
+                    if (currentJavadocParent == null) {
+                        break;
                     }
+
+                    nextJavadocSibling = (JavadocNodeImpl) JavadocUtil
+                            .getNextSibling(currentJavadocParent);
+
+                    nextParseTreeSibling = getNextSibling(parseTreeParent);
                 }
                 currentJavadocParent = nextJavadocSibling;
                 parseTreeParent = nextParseTreeSibling;
@@ -256,7 +253,7 @@ public class JavadocDetailNodeParser {
             final ParseTree currentParseTreeNodeChild = parseTreeParent.getChild(i);
             final JavadocNodeImpl[] subChildren =
                     createChildrenNodes(currentJavadocNode, currentParseTreeNodeChild);
-            currentJavadocNode.setChildren((DetailNode[]) subChildren);
+            currentJavadocNode.setChildren(subChildren);
         }
     }
 
@@ -322,7 +319,7 @@ public class JavadocDetailNodeParser {
         node.setIndex(index);
         node.setType(getTokenType(parseTree));
         node.setParent(parent);
-        node.setChildren((DetailNode[]) new JavadocNodeImpl[parseTree.getChildCount()]);
+        node.setChildren(new JavadocNodeImpl[parseTree.getChildCount()]);
         return node;
     }
 
@@ -413,9 +410,7 @@ public class JavadocDetailNodeParser {
         }
         else {
             final String className = getNodeClassNameWithoutContext(node);
-            final String typeName =
-                    CaseFormat.UPPER_CAMEL.to(CaseFormat.UPPER_UNDERSCORE, className);
-            tokenType = JavadocUtil.getTokenId(typeName);
+            tokenType = JavadocUtil.getTokenId(convertUpperCamelToUpperUnderscore(className));
         }
 
         return tokenType;
@@ -430,7 +425,7 @@ public class JavadocDetailNodeParser {
      */
     private static String getFormattedNodeClassNameWithoutContext(ParseTree node) {
         final String classNameWithoutContext = getNodeClassNameWithoutContext(node);
-        return CaseFormat.UPPER_CAMEL.to(CaseFormat.UPPER_UNDERSCORE, classNameWithoutContext);
+        return convertUpperCamelToUpperUnderscore(classNameWithoutContext);
     }
 
     /**
@@ -528,6 +523,25 @@ public class JavadocDetailNodeParser {
         return offendingToken;
     }
 
+    /**
+     * Converts the given {@code text} from camel case to all upper case with
+     * underscores separating each word.
+     * @param text The string to convert.
+     * @return The result of the conversion.
+     */
+    private static String convertUpperCamelToUpperUnderscore(String text) {
+        final StringBuilder result = new StringBuilder(20);
+        boolean first = true;
+        for (char letter : text.toCharArray()) {
+            if (!first && Character.isUpperCase(letter)) {
+                result.append('_');
+            }
+            result.append(Character.toUpperCase(letter));
+            first = false;
+        }
+        return result.toString();
+    }
+
     /**
      * Custom error listener for JavadocParser that prints user readable errors.
      */
@@ -588,15 +602,14 @@ public class JavadocDetailNodeParser {
 
                 throw new IllegalArgumentException(msg);
             }
-            else {
-                final int ruleIndex = ex.getCtx().getRuleIndex();
-                final String ruleName = recognizer.getRuleNames()[ruleIndex];
-                final String upperCaseRuleName = CaseFormat.UPPER_CAMEL.to(
-                        CaseFormat.UPPER_UNDERSCORE, ruleName);
 
-                errorMessage = new ParseErrorMessage(lineNumber,
-                        MSG_JAVADOC_PARSE_RULE_ERROR, charPositionInLine, msg, upperCaseRuleName);
-            }
+            final int ruleIndex = ex.getCtx().getRuleIndex();
+            final String ruleName = recognizer.getRuleNames()[ruleIndex];
+            final String upperCaseRuleName = convertUpperCamelToUpperUnderscore(ruleName);
+
+            errorMessage = new ParseErrorMessage(lineNumber,
+                    MSG_JAVADOC_PARSE_RULE_ERROR, charPositionInLine, msg, upperCaseRuleName);
+
         }
 
     }
@@ -671,10 +684,12 @@ public class JavadocDetailNodeParser {
         }
 
         /**
-         * Getter for {@link #firstNonTightHtmlTag}.
+         * Getter for the first non-tight HTML tag encountered while parsing javadoc.
          *
          * @return the first non-tight HTML tag that is encountered while parsing Javadoc,
          *     if one exists
+         * @see <a href="https://checkstyle.org/writingjavadocchecks.html#Tight-HTML_rules">
+         *     Tight HTML rules</a>
          */
         public Token getFirstNonTightHtmlTag() {
             return firstNonTightHtmlTag;
@@ -709,7 +724,8 @@ public class JavadocDetailNodeParser {
          * @param messageKey message key
          * @param messageArguments message arguments
          */
-        ParseErrorMessage(int lineNumber, String messageKey, Object... messageArguments) {
+        /* package */ ParseErrorMessage(int lineNumber, String messageKey,
+                Object... messageArguments) {
             this.lineNumber = lineNumber;
             this.messageKey = messageKey;
             this.messageArguments = messageArguments.clone();
