@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -218,20 +218,18 @@ public final class Main {
         // if only we add commons-io library
         final List<File> result = new LinkedList<>();
 
-        if (node.canRead()) {
-            if (!isPathExcluded(node.getAbsolutePath(), patternsToExclude)) {
-                if (node.isDirectory()) {
-                    final File[] files = node.listFiles();
-                    // listFiles() can return null, so we need to check it
-                    if (files != null) {
-                        for (File element : files) {
-                            result.addAll(listFiles(element, patternsToExclude));
-                        }
+        if (node.canRead() && !isPathExcluded(node.getAbsolutePath(), patternsToExclude)) {
+            if (node.isDirectory()) {
+                final File[] files = node.listFiles();
+                // listFiles() can return null, so we need to check it
+                if (files != null) {
+                    for (File element : files) {
+                        result.addAll(listFiles(element, patternsToExclude));
                     }
                 }
-                else if (node.isFile()) {
-                    result.add(node);
-                }
+            }
+            else if (node.isFile()) {
+                result.add(node);
             }
         }
         return result;
@@ -388,7 +386,7 @@ public final class Main {
                 }
 
                 listener = new XpathFileGeneratorAuditListener(getOutputStream(options.outputPath),
-                        AutomaticBean.OutputStreamOptions.NONE);
+                        getOutputStreamOptions(options.outputPath));
             }
             else {
                 listener = createListener(options.format, options.outputPath);
@@ -788,18 +786,7 @@ public final class Main {
                     final String msg = "Could not find config XML file '%s'.";
                     result.add(String.format(Locale.ROOT, msg, configurationFile));
                 }
-
-                // validate optional parameters
-                if (propertiesFile != null && !propertiesFile.exists()) {
-                    result.add(String.format(Locale.ROOT,
-                            "Could not find file '%s'.", propertiesFile));
-                }
-                if (checkerThreadsNumber < 1) {
-                    result.add("Checker threads number must be greater than zero");
-                }
-                if (treeWalkerThreadsNumber < 1) {
-                    result.add("TreeWalker threads number must be greater than zero");
-                }
+                result.addAll(validateOptionalCliParametersIfConfigDefined());
             }
             else {
                 result.add("Must specify a config XML file.");
@@ -807,5 +794,24 @@ public final class Main {
 
             return result;
         }
+
+        /**
+         * Validates optional command line parameters that might be used with config file.
+         * @return list of violations
+         */
+        private List<String> validateOptionalCliParametersIfConfigDefined() {
+            final List<String> result = new ArrayList<>();
+            if (propertiesFile != null && !propertiesFile.exists()) {
+                result.add(String.format(Locale.ROOT,
+                        "Could not find file '%s'.", propertiesFile));
+            }
+            if (checkerThreadsNumber < 1) {
+                result.add("Checker threads number must be greater than zero");
+            }
+            if (treeWalkerThreadsNumber < 1) {
+                result.add("TreeWalker threads number must be greater than zero");
+            }
+            return result;
+        }
     }
 }
