@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -98,6 +98,7 @@ public final class PropertyCacheFile {
      *
      * @param config the current configuration, not null
      * @param fileName the cache file
+     * @throws IllegalArgumentException when either arguments are null
      */
     public PropertyCacheFile(Configuration config, String fileName) {
         if (config == null) {
@@ -145,14 +146,9 @@ public final class PropertyCacheFile {
         if (directory != null) {
             Files.createDirectories(directory);
         }
-        OutputStream out = null;
-        try {
-            out = Files.newOutputStream(path);
+        try (OutputStream out = Files.newOutputStream(path)) {
             details.store(out, null);
         }
-        finally {
-            flushAndCloseOutStream(out);
-        }
     }
 
     /**
@@ -163,18 +159,6 @@ public final class PropertyCacheFile {
         details.setProperty(CONFIG_HASH_KEY, configHash);
     }
 
-    /**
-     * Flushes and closes output stream.
-     * @param stream the output stream
-     * @throws IOException  when there is a problems with file flush and close
-     */
-    private static void flushAndCloseOutStream(OutputStream stream) throws IOException {
-        if (stream != null) {
-            stream.flush();
-            stream.close();
-        }
-    }
-
     /**
      * Checks that file is in cache.
      * @param uncheckedFileName the file to check
@@ -216,6 +200,7 @@ public final class PropertyCacheFile {
      * Calculates the hashcode for the serializable object based on its content.
      * @param object serializable object.
      * @return the hashcode for serializable object.
+     * @throws IllegalStateException when some unexpected happened.
      */
     private static String getHashCodeBasedOnObjectContent(Serializable object) {
         try {
@@ -245,13 +230,9 @@ public final class PropertyCacheFile {
      */
     private static void serialize(Serializable object,
                                   OutputStream outputStream) throws IOException {
-        final ObjectOutputStream oos = new ObjectOutputStream(outputStream);
-        try {
+        try (ObjectOutputStream oos = new ObjectOutputStream(outputStream)) {
             oos.writeObject(object);
         }
-        finally {
-            flushAndCloseOutStream(oos);
-        }
     }
 
     /**
