@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2018 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -33,7 +33,6 @@ import java.util.Objects;
 import java.util.Properties;
 import java.util.stream.Collectors;
 
-import org.apache.tools.ant.AntClassLoader;
 import org.apache.tools.ant.BuildException;
 import org.apache.tools.ant.DirectoryScanner;
 import org.apache.tools.ant.Project;
@@ -63,7 +62,6 @@ import com.puppycrawl.tools.checkstyle.api.SeverityLevelCounter;
 /**
  * An implementation of a ANT task for calling checkstyle. See the documentation
  * of the task for usage.
- * @noinspection ClassLoaderInstantiation
  */
 public class CheckstyleAntTask extends Task {
 
@@ -232,6 +230,7 @@ public class CheckstyleAntTask extends Task {
     /**
      * Sets configuration file.
      * @param configuration the configuration file, URL, or resource to use
+     * @throws BuildException when config was already set
      */
     public void setConfig(String configuration) {
         if (config != null) {
@@ -401,14 +400,6 @@ public class CheckstyleAntTask extends Task {
 
             rootModule = (RootModule) factory.createModule(configuration.getName());
             rootModule.setModuleClassLoader(moduleClassLoader);
-
-            if (rootModule instanceof Checker) {
-                final ClassLoader loader = new AntClassLoader(getProject(),
-                        classpath);
-
-                ((Checker) rootModule).setClassLoader(loader);
-            }
-
             rootModule.configure(configuration);
         }
         catch (final CheckstyleException ex) {
@@ -422,7 +413,6 @@ public class CheckstyleAntTask extends Task {
      * Create the Properties object based on the arguments specified
      * to the ANT task.
      * @return the properties for property expansion expansion
-     * @throws BuildException if an error occurs
      */
     private Properties createOverridingProperties() {
         final Properties returnValue = new Properties();
