@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -158,7 +158,7 @@ public class SuppressWarningsHolder
 
     /**
      * Returns the alias for the source name of a check. If an alias has been
-     * explicitly registered via {@link #registerAlias(String, String)}, that
+     * explicitly registered via {@link #setAliasList(String...)}, that
      * alias is returned; otherwise, the default alias is used.
      * @param sourceName the source name of the check (generally the class
      *        name)
@@ -186,6 +186,7 @@ public class SuppressWarningsHolder
      * Setter to specify aliases for check names that can be used in code
      * within {@code SuppressWarnings}.
      * @param aliasList the list of comma-separated alias assignments
+     * @throws IllegalArgumentException when alias item does not have '='
      */
     public void setAliasList(String... aliasList) {
         for (String sourceAlias : aliasList) {
@@ -549,6 +550,12 @@ public class SuppressWarningsHolder
         return valueList;
     }
 
+    @Override
+    public void destroy() {
+        super.destroy();
+        ENTRIES.remove();
+    }
+
     /** Records a particular suppression for a region of a file. */
     private static class Entry {
 
