@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -615,7 +615,7 @@ public class RequireThisCheck extends AbstractCheck {
         final DetailAST prevSibling = ast.getPreviousSibling();
         if (variableDeclarationFrameType == FrameType.CLASS_FRAME
                 && !validateOnlyOverlapping
-                && (prevSibling == null || ast.getParent().getType() != TokenTypes.DOT)
+                && (prevSibling == null || !isInExpression(ast))
                 && canBeReferencedFromStaticContext(ast)) {
             frameWhereViolationIsFound = variableDeclarationFrame;
         }
@@ -653,6 +653,17 @@ public class RequireThisCheck extends AbstractCheck {
         return frameWhereViolationIsFound;
     }
 
+    /**
+     * Checks ast parent is in expression.
+     *
+     * @param ast token to check
+     * @return true if token is part of expression, false otherwise
+     */
+    private static boolean isInExpression(DetailAST ast) {
+        return TokenTypes.DOT == ast.getParent().getType()
+                || TokenTypes.METHOD_REF == ast.getParent().getType();
+    }
+
     /**
      * Checks whether user arranges 'this' for variable in method, constructor, or block on his own.
      * @param currentFrame current frame.
