@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2018 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -38,62 +38,49 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * by the user. If there is an import but its group is not specified in the
  * configuration such an import should be placed at the end of the import list.
  * </p>
+ * <p>
  * The rule consists of:
- *
- * <p>
- * 1. STATIC group. This group sets the ordering of static imports.
  * </p>
- *
- * <p>
- * 2. SAME_PACKAGE(n) group. This group sets the ordering of the same package imports.
- * Imports are considered on SAME_PACKAGE group if <b>n</b> first domains in package name
- * and import name are identical.
- * </p>
- *
+ * <ol>
+ * <li>
+ * STATIC group. This group sets the ordering of static imports.
+ * </li>
+ * <li>
+ * SAME_PACKAGE(n) group. This group sets the ordering of the same package imports.
+ * Imports are considered on SAME_PACKAGE group if <b>n</b> first domains in package
+ * name and import name are identical:
  * <pre>
- *{@code
- *package java.util.concurrent.locks;
+ * package java.util.concurrent.locks;
  *
- *import java.io.File;
- *import java.util.*; //#1
- *import java.util.List; //#2
- *import java.util.StringTokenizer; //#3
- *import java.util.concurrent.*; //#4
- *import java.util.concurrent.AbstractExecutorService; //#5
- *import java.util.concurrent.locks.LockSupport; //#6
- *import java.util.regex.Pattern; //#7
- *import java.util.regex.Matcher; //#8
- *}
+ * import java.io.File;
+ * import java.util.*; //#1
+ * import java.util.List; //#2
+ * import java.util.StringTokenizer; //#3
+ * import java.util.concurrent.*; //#4
+ * import java.util.concurrent.AbstractExecutorService; //#5
+ * import java.util.concurrent.locks.LockSupport; //#6
+ * import java.util.regex.Pattern; //#7
+ * import java.util.regex.Matcher; //#8
  * </pre>
- *
- * <p>
- * If we have SAME_PACKAGE(3) on configuration file,
- * imports #4-6 will be considered as a SAME_PACKAGE group (java.util.concurrent.*,
- * java.util.concurrent.AbstractExecutorService, java.util.concurrent.locks.LockSupport).
- * SAME_PACKAGE(2) will include #1-8. SAME_PACKAGE(4) will include only #6.
- * SAME_PACKAGE(5) will result in no imports assigned to SAME_PACKAGE group because
- * actual package java.util.concurrent.locks has only 4 domains.
- * </p>
- *
- * <p>
- * 3. THIRD_PARTY_PACKAGE group. This group sets ordering of third party imports.
- * Third party imports are all imports except STATIC,
- * SAME_PACKAGE(n), STANDARD_JAVA_PACKAGE and SPECIAL_IMPORTS.
- * </p>
- *
- * <p>
- * 4. STANDARD_JAVA_PACKAGE group. By default this group sets ordering of standard java/javax
- * imports.
- * </p>
- *
- * <p>
- * 5. SPECIAL_IMPORTS group. This group may contains some imports
- * that have particular meaning for the user.
- * </p>
- *
- * <p>
- * NOTE!
- * </p>
+ * If we have SAME_PACKAGE(3) on configuration file, imports #4-6 will be considered as
+ * a SAME_PACKAGE group (java.util.concurrent.*, java.util.concurrent.AbstractExecutorService,
+ * java.util.concurrent.locks.LockSupport). SAME_PACKAGE(2) will include #1-8.
+ * SAME_PACKAGE(4) will include only #6. SAME_PACKAGE(5) will result in no imports assigned
+ * to SAME_PACKAGE group because actual package java.util.concurrent.locks has only 4 domains.
+ * </li>
+ * <li>
+ * THIRD_PARTY_PACKAGE group. This group sets ordering of third party imports.
+ * Third party imports are all imports except STATIC, SAME_PACKAGE(n), STANDARD_JAVA_PACKAGE and
+ * SPECIAL_IMPORTS.
+ * </li>
+ * <li>
+ * STANDARD_JAVA_PACKAGE group. By default this group sets ordering of standard java/javax imports.
+ * </li>
+ * <li>
+ * SPECIAL_IMPORTS group. This group may contains some imports that have particular meaning for the
+ * user.
+ * </li>
+ * </ol>
  * <p>
  * Use the separator '###' between rules.
  * </p>
@@ -108,146 +95,208 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * </p>
  * <ol>
  * <li>
- *    STATIC has top priority
+ * STATIC has top priority
  * </li>
  * <li>
- *    SAME_PACKAGE has second priority
+ * SAME_PACKAGE has second priority
  * </li>
  * <li>
- *    STANDARD_JAVA_PACKAGE and SPECIAL_IMPORTS will compete using "best match" rule: longer
- *    matching substring wins; in case of the same length, lower position of matching substring
- *    wins; if position is the same, order of rules in configuration solves the puzzle.
+ * STANDARD_JAVA_PACKAGE and SPECIAL_IMPORTS will compete using "best match" rule: longer
+ * matching substring wins; in case of the same length, lower position of matching substring
+ * wins; if position is the same, order of rules in configuration solves the puzzle.
  * </li>
  * <li>
- *    THIRD_PARTY has the least priority
+ * THIRD_PARTY has the least priority
  * </li>
  * </ol>
  * <p>
- *    Few examples to illustrate "best match":
+ * Few examples to illustrate "best match":
  * </p>
  * <p>
- *    1. patterns STANDARD_JAVA_PACKAGE = "Check", SPECIAL_IMPORTS="ImportOrderCheck" and input
- *    file:
+ * 1. patterns STANDARD_JAVA_PACKAGE = "Check", SPECIAL_IMPORTS="ImportOrderCheck" and input file:
  * </p>
  * <pre>
- *{@code
- *import com.puppycrawl.tools.checkstyle.checks.imports.CustomImportOrderCheck;
- *import com.puppycrawl.tools.checkstyle.checks.imports.ImportOrderCheck;}
+ * import com.puppycrawl.tools.checkstyle.checks.imports.CustomImportOrderCheck;
+ * import com.puppycrawl.tools.checkstyle.checks.imports.ImportOrderCheck;
  * </pre>
  * <p>
- *    Result: imports will be assigned to SPECIAL_IMPORTS, because matching substring length is 16.
- *    Matching substring for STANDARD_JAVA_PACKAGE is 5.
+ * Result: imports will be assigned to SPECIAL_IMPORTS, because matching substring length is 16.
+ * Matching substring for STANDARD_JAVA_PACKAGE is 5.
  * </p>
  * <p>
- *    2. patterns STANDARD_JAVA_PACKAGE = "Check", SPECIAL_IMPORTS="Avoid" and file:
+ * 2. patterns STANDARD_JAVA_PACKAGE = "Check", SPECIAL_IMPORTS="Avoid" and file:
  * </p>
  * <pre>
- *{@code
- *import com.puppycrawl.tools.checkstyle.checks.imports.AvoidStarImportCheck;}
+ * import com.puppycrawl.tools.checkstyle.checks.imports.AvoidStarImportCheck;
  * </pre>
  * <p>
- *   Result: import will be assigned to SPECIAL_IMPORTS. Matching substring length is 5 for both
- *   patterns. However, "Avoid" position is lower then "Check" position.
+ * Result: import will be assigned to SPECIAL_IMPORTS. Matching substring length is 5 for both
+ * patterns. However, "Avoid" position is lower than "Check" position.
  * </p>
- *
- * <pre>
- *    Properties:
- * </pre>
- * <table summary="Properties" border="1">
- *     <tr><th>name</th><th>Description</th><th>type</th><th>default value</th></tr>
- *      <tr><td>customImportOrderRules</td><td>List of order declaration customizing by user.</td>
- *          <td>string</td><td>null</td></tr>
- *      <tr><td>standardPackageRegExp</td><td>RegExp for STANDARD_JAVA_PACKAGE group imports.</td>
- *          <td>regular expression</td><td>^(java|javax)\.</td></tr>
- *      <tr><td>thirdPartyPackageRegExp</td><td>RegExp for THIRD_PARTY_PACKAGE group imports.</td>
- *          <td>regular expression</td><td>.*</td></tr>
- *      <tr><td>specialImportsRegExp</td><td>RegExp for SPECIAL_IMPORTS group imports.</td>
- *          <td>regular expression</td><td>^$</td></tr>
- *      <tr><td>separateLineBetweenGroups</td><td>Force empty line separator between import groups.
- *          </td><td>boolean</td><td>true</td></tr>
- *      <tr><td>sortImportsInGroupAlphabetically</td><td>Force grouping alphabetically,
- *          in ASCII sort order.</td><td>boolean</td><td>false</td></tr>
- * </table>
- *
+ * <ul>
+ * <li>
+ * Property {@code customImportOrderRules} - Specify list of order declaration customizing by user.
+ * Default value is {@code {}}.
+ * </li>
+ * <li>
+ * Property {@code standardPackageRegExp} - Specify RegExp for STANDARD_JAVA_PACKAGE group imports.
+ * Default value is {@code "^(java|javax)\."}.
+ * </li>
+ * <li>
+ * Property {@code thirdPartyPackageRegExp} - Specify RegExp for THIRD_PARTY_PACKAGE group imports.
+ * Default value is {@code ".*"}.
+ * </li>
+ * <li>
+ * Property {@code specialImportsRegExp} - Specify RegExp for SPECIAL_IMPORTS group imports.
+ * Default value is {@code "^$" (empty)}.
+ * </li>
+ * <li>
+ * Property {@code separateLineBetweenGroups} - Force empty line separator between
+ * import groups.
+ * Default value is {@code true}.
+ * </li>
+ * <li>
+ * Property {@code sortImportsInGroupAlphabetically} - Force grouping alphabetically,
+ * in <a href="https://en.wikipedia.org/wiki/ASCII#Order">ASCII sort order</a>.
+ * Default value is {@code false}.
+ * </li>
+ * </ul>
  * <p>
- * For example:
+ * To configure the check so that it matches default Eclipse formatter configuration
+ * (tested on Kepler and Luna releases):
  * </p>
- *        <p>To configure the check so that it matches default Eclipse formatter configuration
- *        (tested on Kepler, Luna and Mars):</p>
- *        <ul>
- *          <li>group of static imports is on the top</li>
- *          <li>groups of non-static imports: &quot;java&quot; and &quot;javax&quot; packages
- *          first, then &quot;org&quot; and then all other imports</li>
- *          <li>imports will be sorted in the groups</li>
- *          <li>groups are separated by, at least, one blank line</li>
- *        </ul>
+ * <ul>
+ * <li>
+ * group of static imports is on the top
+ * </li>
+ * <li>
+ * groups of non-static imports: "java" and "javax" packages first, then "org" and then all other
+ * imports
+ * </li>
+ * <li>
+ * imports will be sorted in the groups
+ * </li>
+ * <li>
+ * groups are separated by single blank line
+ * </li>
+ * </ul>
+ * <p>
+ * Notes:
+ * </p>
+ * <ul>
+ * <li>
+ * "com" package is not mentioned on configuration, because it is ignored by Eclipse Kepler and Luna
+ * (looks like Eclipse defect)
+ * </li>
+ * <li>
+ * configuration below doesn't work in all 100% cases due to inconsistent behavior prior to Mars
+ * release, but covers most scenarios
+ * </li>
+ * </ul>
  * <pre>
  * &lt;module name=&quot;CustomImportOrder&quot;&gt;
- *    &lt;property name=&quot;customImportOrderRules&quot;
- *        value=&quot;STATIC###STANDARD_JAVA_PACKAGE###SPECIAL_IMPORTS&quot;/&gt;
- *    &lt;property name=&quot;specialImportsRegExp&quot; value=&quot;org&quot;/&gt;
- *    &lt;property name=&quot;sortImportsInGroupAlphabetically&quot; value=&quot;true&quot;/&gt;
- *    &lt;property name=&quot;separateLineBetweenGroups&quot; value=&quot;true&quot;/&gt;
+ *   &lt;property name=&quot;customImportOrderRules&quot;
+ *     value=&quot;STATIC###STANDARD_JAVA_PACKAGE###SPECIAL_IMPORTS&quot;/&gt;
+ *   &lt;property name=&quot;specialImportsRegExp&quot; value=&quot;^org\.&quot;/&gt;
+ *   &lt;property name=&quot;sortImportsInGroupAlphabetically&quot; value=&quot;true&quot;/&gt;
+ *   &lt;property name=&quot;separateLineBetweenGroups&quot; value=&quot;true&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
- *
- *        <p>To configure the check so that it matches default IntelliJ IDEA formatter
- *        configuration (tested on v14):</p>
- *        <ul>
- *          <li>group of static imports is on the bottom</li>
- *          <li>groups of non-static imports: all imports except of &quot;javax&quot;
- *          and &quot;java&quot;, then &quot;javax&quot; and &quot;java&quot;</li>
- *          <li>imports will be sorted in the groups</li>
- *          <li>groups are separated by, at least, one blank line</li>
- *        </ul>
- *
- *        <p>
- *        Note: &quot;separated&quot; option is disabled because IDEA default has blank line
- *        between &quot;java&quot; and static imports, and no blank line between
- *        &quot;javax&quot; and &quot;java&quot;
- *        </p>
- *
- * <pre>
- * &lt;module name=&quot;CustomImportOrder&quot;&gt;
- *    &lt;property name=&quot;customImportOrderRules&quot;
- *        value=&quot;THIRD_PARTY_PACKAGE###SPECIAL_IMPORTS###STANDARD_JAVA_PACKAGE
- *        ###STATIC&quot;/&gt;
- *    &lt;property name=&quot;specialImportsRegExp&quot; value=&quot;^javax\.&quot;/&gt;
- *    &lt;property name=&quot;standardPackageRegExp&quot; value=&quot;^java\.&quot;/&gt;
- *    &lt;property name=&quot;sortImportsInGroupAlphabetically&quot; value=&quot;true&quot;/&gt;
- *    &lt;property name=&quot;separateLineBetweenGroups&quot; value=&quot;false&quot;/&gt;
- *&lt;/module&gt;
- * </pre>
- *
- * <p>To configure the check so that it matches default NetBeans formatter
- *    configuration (tested on v8):</p>
+ * <p>
+ * To configure the check so that it matches default Eclipse formatter configuration
+ * (tested on Mars release):
+ * </p>
  * <ul>
- *     <li>groups of non-static imports are not defined, all imports will be sorted as a one
- *         group</li>
- *     <li>static imports are not separated, they will be sorted along with other imports</li>
+ * <li>
+ * group of static imports is on the top
+ * </li>
+ * <li>
+ * groups of non-static imports: "java" and "javax" packages first, then "org" and "com",
+ * then all other imports as one group
+ * </li>
+ * <li>
+ * imports will be sorted in the groups
+ * </li>
+ * <li>
+ * groups are separated by one blank line
+ * </li>
  * </ul>
- *
- * <pre>
- *&lt;module name=&quot;CustomImportOrder&quot;/&gt;
- * </pre>
- * <p>To set RegExps for THIRD_PARTY_PACKAGE and STANDARD_JAVA_PACKAGE groups use
- *         thirdPartyPackageRegExp and standardPackageRegExp options.</p>
  * <pre>
  * &lt;module name=&quot;CustomImportOrder&quot;&gt;
- *    &lt;property name=&quot;customImportOrderRules&quot;
- *    value=&quot;STATIC###SAME_PACKAGE(3)###THIRD_PARTY_PACKAGE###STANDARD_JAVA_PACKAGE&quot;/&gt;
- *    &lt;property name=&quot;thirdPartyPackageRegExp&quot; value=&quot;com|org&quot;/&gt;
- *    &lt;property name=&quot;standardPackageRegExp&quot; value=&quot;^(java|javax)\.&quot;/&gt;
+ *   &lt;property name=&quot;customImportOrderRules&quot;
+ *     value=&quot;STATIC###STANDARD_JAVA_PACKAGE###SPECIAL_IMPORTS###THIRD_PARTY_PACKAGE&quot;/&gt;
+ *   &lt;property name=&quot;specialImportsRegExp&quot; value=&quot;^org\.&quot;/&gt;
+ *   &lt;property name=&quot;thirdPartyPackageRegExp&quot; value=&quot;^com\.&quot;/&gt;
+ *   &lt;property name=&quot;sortImportsInGroupAlphabetically&quot; value=&quot;true&quot;/&gt;
+ *   &lt;property name=&quot;separateLineBetweenGroups&quot; value=&quot;true&quot;/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>
+ * To configure the check so that it matches default IntelliJ IDEA formatter configuration
+ * (tested on v14):
+ * </p>
+ * <ul>
+ * <li>
+ * group of static imports is on the bottom
+ * </li>
+ * <li>
+ * groups of non-static imports: all imports except of "javax" and "java", then "javax" and "java"
+ * </li>
+ * <li>
+ * imports will be sorted in the groups
+ * </li>
+ * <li>
+ * groups are separated by one blank line
+ * </li>
+ * </ul>
+ * <p>
+ * Note: "separated" option is disabled because IDEA default has blank line between "java" and
+ * static imports, and no blank line between "javax" and "java"
+ * </p>
+ * <pre>
+ * &lt;module name="CustomImportOrder"&gt;
+ *   &lt;property name="customImportOrderRules"
+ *     value="THIRD_PARTY_PACKAGE###SPECIAL_IMPORTS###STANDARD_JAVA_PACKAGE###STATIC"/&gt;
+ *   &lt;property name="specialImportsRegExp" value="^javax\."/&gt;
+ *   &lt;property name="standardPackageRegExp" value="^java\."/&gt;
+ *   &lt;property name="sortImportsInGroupAlphabetically" value="true"/&gt;
+ *   &lt;property name="separateLineBetweenGroups" value="false"/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>
+ * To configure the check so that it matches default NetBeans formatter configuration
+ * (tested on v8):
+ * </p>
+ * <ul>
+ * <li>
+ * groups of non-static imports are not defined, all imports will be sorted as a one group
+ * </li>
+ * <li>
+ * static imports are not separated, they will be sorted along with other imports
+ * </li>
+ * </ul>
+ * <pre>
+ * &lt;module name=&quot;CustomImportOrder&quot;/&gt;
+ * </pre>
+ * <p>
+ * To set RegExps for THIRD_PARTY_PACKAGE and STANDARD_JAVA_PACKAGE groups use
+ * thirdPartyPackageRegExp and standardPackageRegExp options.
+ * </p>
+ * <pre>
+ * &lt;module name=&quot;CustomImportOrder&quot;&gt;
+ *   &lt;property name=&quot;customImportOrderRules&quot;
+ *     value=&quot;STATIC###SAME_PACKAGE(3)###THIRD_PARTY_PACKAGE###STANDARD_JAVA_PACKAGE&quot;/&gt;
+ *   &lt;property name=&quot;thirdPartyPackageRegExp&quot; value=&quot;^(com|org)\.&quot;/&gt;
+ *   &lt;property name=&quot;standardPackageRegExp&quot; value=&quot;^(java|javax)\.&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
  * <p>
  * Also, this check can be configured to force empty line separator between
- * import groups. For example
+ * import groups. For example.
  * </p>
- *
  * <pre>
  * &lt;module name=&quot;CustomImportOrder&quot;&gt;
- *    &lt;property name=&quot;separateLineBetweenGroups&quot; value=&quot;true&quot;/&gt;
+ *   &lt;property name=&quot;separateLineBetweenGroups&quot; value=&quot;true&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
  * <p>
@@ -257,26 +306,23 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * </p>
  * <pre>
  * &lt;module name=&quot;CustomImportOrder&quot;&gt;
- *    &lt;property name=&quot;sortImportsInGroupAlphabetically&quot; value=&quot;true&quot;/&gt;
+ *   &lt;property name=&quot;sortImportsInGroupAlphabetically&quot; value=&quot;true&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
  * <p>
  * Example of ASCII order:
  * </p>
  * <pre>
- * {@code
- *import java.awt.Dialog;
- *import java.awt.Window;
- *import java.awt.color.ColorSpace;
- *import java.awt.Frame; // violation here - in ASCII order 'F' should go before 'c',
- *                       // as all uppercase come before lowercase letters}
+ * import java.awt.Dialog;
+ * import java.awt.Window;
+ * import java.awt.color.ColorSpace;
+ * import java.awt.Frame; // violation here - in ASCII order 'F' should go before 'c',
+ *                        // as all uppercase come before lowercase letters
  * </pre>
  * <p>
  * To force checking imports sequence such as:
  * </p>
- *
  * <pre>
- * {@code
  * package com.puppycrawl.tools.checkstyle.imports;
  *
  * import com.google.common.annotations.GwtCompatible;
@@ -289,17 +335,20 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  *
  * import com.google.common.annotations.GwtCompatible; // violation here - should be in the
  *                                                     // THIRD_PARTY_PACKAGE group
- * import android.*;}
+ * import android.*;
  * </pre>
+ * <p>
  * configure as follows:
+ * </p>
  * <pre>
  * &lt;module name=&quot;CustomImportOrder&quot;&gt;
- *    &lt;property name=&quot;customImportOrderRules&quot;
- *    value=&quot;SAME_PACKAGE(3)###THIRD_PARTY_PACKAGE###STATIC###SPECIAL_IMPORTS&quot;/&gt;
- *    &lt;property name=&quot;specialImportsRegExp&quot; value=&quot;android.*&quot;/&gt;
+ *   &lt;property name=&quot;customImportOrderRules&quot;
+ *     value=&quot;SAME_PACKAGE(3)###THIRD_PARTY_PACKAGE###STATIC###SPECIAL_IMPORTS&quot;/&gt;
+ *   &lt;property name=&quot;specialImportsRegExp&quot; value=&quot;^android\.&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
  *
+ * @since 5.8
  */
 @FileStatefulCheck
 public class CustomImportOrderCheck extends AbstractCheck {
@@ -310,6 +359,12 @@ public class CustomImportOrderCheck extends AbstractCheck {
      */
     public static final String MSG_LINE_SEPARATOR = "custom.import.order.line.separator";
 
+    /**
+     * A key is pointing to the warning message text in "messages.properties"
+     * file.
+     */
+    public static final String MSG_SEPARATED_IN_GROUP = "custom.import.order.separated.internally";
+
     /**
      * A key is pointing to the warning message text in "messages.properties"
      * file.
@@ -355,35 +410,38 @@ public class CustomImportOrderCheck extends AbstractCheck {
     /** Pattern used to separate groups of imports. */
     private static final Pattern GROUP_SEPARATOR_PATTERN = Pattern.compile("\\s*###\\s*");
 
-    /** List of order declaration customizing by user. */
+    /** Specify list of order declaration customizing by user. */
     private final List<String> customImportOrderRules = new ArrayList<>();
 
     /** Contains objects with import attributes. */
     private final List<ImportDetails> importToGroupList = new ArrayList<>();
 
-    /** RegExp for SAME_PACKAGE group imports. */
+    /** Specify RegExp for SAME_PACKAGE group imports. */
     private String samePackageDomainsRegExp = "";
 
-    /** RegExp for STANDARD_JAVA_PACKAGE group imports. */
+    /** Specify RegExp for STANDARD_JAVA_PACKAGE group imports. */
     private Pattern standardPackageRegExp = Pattern.compile("^(java|javax)\\.");
 
-    /** RegExp for THIRD_PARTY_PACKAGE group imports. */
+    /** Specify RegExp for THIRD_PARTY_PACKAGE group imports. */
     private Pattern thirdPartyPackageRegExp = Pattern.compile(".*");
 
-    /** RegExp for SPECIAL_IMPORTS group imports. */
+    /** Specify RegExp for SPECIAL_IMPORTS group imports. */
     private Pattern specialImportsRegExp = Pattern.compile("^$");
 
     /** Force empty line separator between import groups. */
     private boolean separateLineBetweenGroups = true;
 
-    /** Force grouping alphabetically, in ASCII order. */
+    /**
+     * Force grouping alphabetically,
+     * in <a href="https://en.wikipedia.org/wiki/ASCII#Order"> ASCII sort order</a>.
+     */
     private boolean sortImportsInGroupAlphabetically;
 
     /** Number of first domains for SAME_PACKAGE group. */
     private int samePackageMatchingDepth = 2;
 
     /**
-     * Sets standardRegExp specified by user.
+     * Setter to specify RegExp for STANDARD_JAVA_PACKAGE group imports.
      * @param regexp
      *        user value.
      */
@@ -392,7 +450,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
     }
 
     /**
-     * Sets thirdPartyRegExp specified by user.
+     * Setter to specify RegExp for THIRD_PARTY_PACKAGE group imports.
      * @param regexp
      *        user value.
      */
@@ -401,7 +459,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
     }
 
     /**
-     * Sets specialImportsRegExp specified by user.
+     * Setter to specify RegExp for SPECIAL_IMPORTS group imports.
      * @param regexp
      *        user value.
      */
@@ -410,7 +468,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
     }
 
     /**
-     * Sets separateLineBetweenGroups specified by user.
+     * Setter to force empty line separator between import groups.
      * @param value
      *        user value.
      */
@@ -419,7 +477,8 @@ public class CustomImportOrderCheck extends AbstractCheck {
     }
 
     /**
-     * Sets sortImportsInGroupAlphabetically specified by user.
+     * Setter to force grouping alphabetically, in
+     * <a href="https://en.wikipedia.org/wiki/ASCII#Order">ASCII sort order</a>.
      * @param value
      *        user value.
      */
@@ -428,8 +487,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
     }
 
     /**
-     * Sets a custom import order from the rules in the string format specified
-     * by user.
+     * Setter to specify list of order declaration customizing by user.
      * @param inputCustomImportOrder
      *        user value.
      */
@@ -475,9 +533,10 @@ public class CustomImportOrderCheck extends AbstractCheck {
         else {
             final String importFullPath = getFullImportIdent(ast);
             final int lineNo = ast.getLineNo();
+            final int endLineNo = ast.getLastChild().getLineNo();
             final boolean isStatic = ast.getType() == TokenTypes.STATIC_IMPORT;
             importToGroupList.add(new ImportDetails(importFullPath,
-                    lineNo, getImportGroup(isStatic, importFullPath),
+                    lineNo, endLineNo, getImportGroup(isStatic, importFullPath),
                     isStatic));
         }
     }
@@ -491,56 +550,143 @@ public class CustomImportOrderCheck extends AbstractCheck {
 
     /** Examine the order of all the imports and log any violations. */
     private void finishImportList() {
-        final ImportDetails firstImport = importToGroupList.get(0);
-        String currentGroup = getImportGroup(firstImport.isStaticImport(),
-                firstImport.getImportFullPath());
+        String currentGroup = getFirstGroup();
         int currentGroupNumber = customImportOrderRules.indexOf(currentGroup);
+        ImportDetails previousImportObjectFromCurrentGroup = null;
         String previousImportFromCurrentGroup = null;
 
         for (ImportDetails importObject : importToGroupList) {
             final String importGroup = importObject.getImportGroup();
             final String fullImportIdent = importObject.getImportFullPath();
 
-            if (getCountOfEmptyLinesBefore(importObject.getLineNumber()) > 1) {
-                log(importObject.getLineNumber(), MSG_LINE_SEPARATOR, fullImportIdent);
-            }
             if (importGroup.equals(currentGroup)) {
-                if (sortImportsInGroupAlphabetically
-                        && previousImportFromCurrentGroup != null
-                        && compareImports(fullImportIdent, previousImportFromCurrentGroup) < 0) {
-                    log(importObject.getLineNumber(), MSG_LEX,
+                validateExtraEmptyLine(previousImportObjectFromCurrentGroup,
+                        importObject, fullImportIdent);
+                if (isAlphabeticalOrderBroken(previousImportFromCurrentGroup, fullImportIdent)) {
+                    log(importObject.getStartLineNumber(), MSG_LEX,
                             fullImportIdent, previousImportFromCurrentGroup);
                 }
                 else {
                     previousImportFromCurrentGroup = fullImportIdent;
                 }
+                previousImportObjectFromCurrentGroup = importObject;
             }
             else {
                 //not the last group, last one is always NON_GROUP
                 if (customImportOrderRules.size() > currentGroupNumber + 1) {
                     final String nextGroup = getNextImportGroup(currentGroupNumber + 1);
                     if (importGroup.equals(nextGroup)) {
-                        if (separateLineBetweenGroups
-                                && getCountOfEmptyLinesBefore(importObject.getLineNumber()) == 0) {
-                            log(importObject.getLineNumber(), MSG_LINE_SEPARATOR, fullImportIdent);
-                        }
+                        validateMissedEmptyLine(previousImportObjectFromCurrentGroup,
+                                importObject, fullImportIdent);
                         currentGroup = nextGroup;
                         currentGroupNumber = customImportOrderRules.indexOf(nextGroup);
                         previousImportFromCurrentGroup = fullImportIdent;
                     }
                     else {
-                        logWrongImportGroupOrder(importObject.getLineNumber(),
+                        logWrongImportGroupOrder(importObject.getStartLineNumber(),
                                 importGroup, nextGroup, fullImportIdent);
                     }
+                    previousImportObjectFromCurrentGroup = importObject;
                 }
                 else {
-                    logWrongImportGroupOrder(importObject.getLineNumber(),
+                    logWrongImportGroupOrder(importObject.getStartLineNumber(),
                             importGroup, currentGroup, fullImportIdent);
                 }
             }
         }
     }
 
+    /**
+     * Log violation if empty line is missed.
+     * @param previousImport previous import from current group.
+     * @param importObject current import.
+     * @param fullImportIdent full import identifier.
+     */
+    private void validateMissedEmptyLine(ImportDetails previousImport,
+                                         ImportDetails importObject, String fullImportIdent) {
+        if (isEmptyLineMissed(previousImport, importObject)) {
+            log(importObject.getStartLineNumber(), MSG_LINE_SEPARATOR, fullImportIdent);
+        }
+    }
+
+    /**
+     * Log violation if extra empty line is present.
+     * @param previousImport previous import from current group.
+     * @param importObject current import.
+     * @param fullImportIdent full import identifier.
+     */
+    private void validateExtraEmptyLine(ImportDetails previousImport,
+                                        ImportDetails importObject, String fullImportIdent) {
+        if (isSeparatedByExtraEmptyLine(previousImport, importObject)) {
+            log(importObject.getStartLineNumber(), MSG_SEPARATED_IN_GROUP, fullImportIdent);
+        }
+    }
+
+    /**
+     * Get first import group.
+     *
+     * @return
+     *        first import group of file.
+     */
+    private String getFirstGroup() {
+        final ImportDetails firstImport = importToGroupList.get(0);
+        return getImportGroup(firstImport.isStaticImport(),
+                firstImport.getImportFullPath());
+    }
+
+    /**
+     * Examine alphabetical order of imports.
+     *
+     * @param previousImport
+     *        previous import of current group.
+     * @param currentImport
+     *        current import.
+     * @return
+     *        true, if previous and current import are not in alphabetical order.
+     */
+    private boolean isAlphabeticalOrderBroken(String previousImport,
+                                              String currentImport) {
+        return sortImportsInGroupAlphabetically
+                && previousImport != null
+                && compareImports(currentImport, previousImport) < 0;
+    }
+
+    /**
+     * Examine empty lines between groups.
+     *
+     * @param previousImportObject
+     *        previous import in current group.
+     * @param currentImportObject
+     *        current import.
+     * @return
+     *        true, if current import NOT separated from previous import by empty line.
+     */
+    private boolean isEmptyLineMissed(ImportDetails previousImportObject,
+                                      ImportDetails currentImportObject) {
+        return separateLineBetweenGroups
+                && getCountOfEmptyLinesBetween(
+                     previousImportObject.getEndLineNumber(),
+                     currentImportObject.getStartLineNumber()) != 1;
+    }
+
+    /**
+     * Examine that imports separated by more than one empty line.
+     *
+     * @param previousImportObject
+     *        previous import in current group.
+     * @param currentImportObject
+     *        current import.
+     * @return
+     *        true, if current import separated from previous by more that one empty line.
+     */
+    private boolean isSeparatedByExtraEmptyLine(ImportDetails previousImportObject,
+                                                ImportDetails currentImportObject) {
+        return previousImportObject != null
+                && getCountOfEmptyLinesBetween(
+                     previousImportObject.getEndLineNumber(),
+                     currentImportObject.getStartLineNumber()) > 0;
+    }
+
     /**
      * Log wrong import group order.
      * @param currentImportLine
@@ -644,9 +790,11 @@ public class CustomImportOrderCheck extends AbstractCheck {
         return bestMatch.group;
     }
 
-    /** Tries to find better matching regular expression:
+    /**
+     * Tries to find better matching regular expression:
      * longer matching substring wins; in case of the same length,
      * lower position of matching substring wins.
+     *
      * @param importPath
      *      Full import identifier
      * @param group
@@ -702,21 +850,23 @@ public class CustomImportOrderCheck extends AbstractCheck {
     }
 
     /**
-     * Counts empty lines before given.
-     * @param lineNo
-     *        Line number of current import.
-     * @return count of empty lines before given.
+     * Counts empty lines between given parameters.
+     * @param fromLineNo
+     *        One-based line number of previous import.
+     * @param toLineNo
+     *        One-based line number of current import.
+     * @return count of empty lines between given parameters, exclusive,
+     *        eg., (fromLineNo, toLineNo).
      */
-    private int getCountOfEmptyLinesBefore(int lineNo) {
+    private int getCountOfEmptyLinesBetween(int fromLineNo, int toLineNo) {
         int result = 0;
         final String[] lines = getLines();
-        //  [lineNo - 2] is the number of the previous line
-        //  because the numbering starts from zero.
-        int lineBeforeIndex = lineNo - 2;
-        while (lineBeforeIndex >= 0
-                && CommonUtil.isBlank(lines[lineBeforeIndex])) {
-            lineBeforeIndex--;
-            result++;
+
+        for (int i = fromLineNo + 1; i <= toLineNo - 1; i++) {
+            // "- 1" because the numbering is one-based
+            if (CommonUtil.isBlank(lines[i - 1])) {
+                result++;
+            }
         }
         return result;
     }
@@ -739,6 +889,8 @@ public class CustomImportOrderCheck extends AbstractCheck {
      * Parses ordering rule and adds it to the list with rules.
      * @param ruleStr
      *        String with rule.
+     * @throws IllegalArgumentException when SAME_PACKAGE rule parameter is not positive integer
+     * @throws IllegalStateException when ruleStr is unexpected value
      */
     private void addRulesToList(String ruleStr) {
         if (STATIC_RULE_GROUP.equals(ruleStr)
@@ -783,7 +935,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
      * @param packageFullPath
      *        full identifier containing path to package or imported object.
      * @return String with defined amount of domains or full identifier
-     *        (if full identifier had less domain then specified)
+     *        (if full identifier had less domain than specified)
      */
     private static String getFirstDomainsFromIdent(
             final int firstPackageDomainsCount, final String packageFullPath) {
@@ -807,8 +959,15 @@ public class CustomImportOrderCheck extends AbstractCheck {
         /** Import full path. */
         private final String importFullPath;
 
-        /** Import line number. */
-        private final int lineNumber;
+        /** Import start line number. */
+        private final int startLineNumber;
+
+        /**
+         * Import end line number.
+         * Note: It can be different from <b>startLineNumber</b> when import statement span
+         * multiple lines.
+         */
+        private final int endLineNumber;
 
         /** Import group. */
         private final String importGroup;
@@ -817,20 +976,23 @@ public class CustomImportOrderCheck extends AbstractCheck {
         private final boolean staticImport;
 
         /**
-         * Initialise importFullPath, lineNumber, importGroup, staticImport.
+         * Initialise importFullPath, startLineNumber, endLineNumber, importGroup, staticImport.
          * @param importFullPath
          *        import full path.
-         * @param lineNumber
-         *        import line number.
+         * @param startLineNumber
+         *        import start line number.
+         * @param endLineNumber
+         *        import end line number.
          * @param importGroup
          *        import group.
          * @param staticImport
          *        if import is static.
          */
-        ImportDetails(String importFullPath,
-                int lineNumber, String importGroup, boolean staticImport) {
+        /* package */ ImportDetails(String importFullPath, int startLineNumber, int endLineNumber,
+                                    String importGroup, boolean staticImport) {
             this.importFullPath = importFullPath;
-            this.lineNumber = lineNumber;
+            this.startLineNumber = startLineNumber;
+            this.endLineNumber = endLineNumber;
             this.importGroup = importGroup;
             this.staticImport = staticImport;
         }
@@ -844,11 +1006,19 @@ public class CustomImportOrderCheck extends AbstractCheck {
         }
 
         /**
-         * Get import line number.
-         * @return import line.
+         * Get import start line number.
+         * @return import start line.
          */
-        public int getLineNumber() {
-            return lineNumber;
+        public int getStartLineNumber() {
+            return startLineNumber;
+        }
+
+        /**
+         * Get import end line number.
+         * @return import end line.
+         */
+        public int getEndLineNumber() {
+            return endLineNumber;
         }
 
         /**
@@ -882,7 +1052,9 @@ public class CustomImportOrderCheck extends AbstractCheck {
         /** Import group for current best match. */
         private String group;
 
-        /** Constructor to initialize the fields.
+        /**
+         * Constructor to initialize the fields.
+         *
          * @param group
          *        Matched group.
          * @param length
@@ -890,7 +1062,7 @@ public class CustomImportOrderCheck extends AbstractCheck {
          * @param position
          *        Matching position.
          */
-        RuleMatchForImport(String group, int length, int position) {
+        /* package */ RuleMatchForImport(String group, int length, int position) {
             this.group = group;
             matchLength = length;
             matchPosition = position;
