@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2018 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -25,6 +25,7 @@ import java.util.HashSet;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
+import java.util.stream.Collectors;
 
 import com.puppycrawl.tools.checkstyle.JavadocDetailNodeParser;
 import com.puppycrawl.tools.checkstyle.JavadocDetailNodeParser.ParseErrorMessage;
@@ -87,7 +88,6 @@ public abstract class AbstractJavadocCheck extends AbstractCheck {
      * generally tend to be fine with non tight html. It can be set through config file if a check
      * is to log violation upon encountering non-tight HTML in javadoc.
      *
-     * @see ParseStatus#firstNonTightHtmlTag
      * @see ParseStatus#isNonTight()
      * @see <a href="https://checkstyle.org/writingjavadocchecks.html#Tight-HTML_rules">
      *     Tight HTML rules</a>
@@ -148,10 +148,12 @@ public abstract class AbstractJavadocCheck extends AbstractCheck {
     }
 
     /**
-     * Setter for {@link #violateExecutionOnNonTightHtml}.
+     * Setter to control when to print violations if the Javadoc being examined by this check
+     * violates the tight html rules defined at
+     * <a href="https://checkstyle.org/writingjavadocchecks.html#Tight-HTML_rules">
+     *     Tight-HTML Rules</a>.
+     *
      * @param shouldReportViolation value to which the field shall be set to
-     * @see <a href="https://checkstyle.org/writingjavadocchecks.html#Tight-HTML_rules">
-     *     Tight HTML rules</a>
      */
     public final void setViolateExecutionOnNonTightHtml(boolean shouldReportViolation) {
         violateExecutionOnNonTightHtml = shouldReportViolation;
@@ -172,9 +174,8 @@ public abstract class AbstractJavadocCheck extends AbstractCheck {
     public void init() {
         validateDefaultJavadocTokens();
         if (javadocTokens.isEmpty()) {
-            for (int id : getDefaultJavadocTokens()) {
-                javadocTokens.add(id);
-            }
+            javadocTokens.addAll(
+                    Arrays.stream(getDefaultJavadocTokens()).boxed().collect(Collectors.toList()));
         }
         else {
             final int[] acceptableJavadocTokens = getAcceptableJavadocTokens();
@@ -275,7 +276,7 @@ public abstract class AbstractJavadocCheck extends AbstractCheck {
 
     @Override
     public final void finishTree(DetailAST rootAST) {
-        TREE_CACHE.get().clear();
+        // No code, prevent override in subclasses
     }
 
     @Override
@@ -377,6 +378,13 @@ public abstract class AbstractJavadocCheck extends AbstractCheck {
         return javadocTokens.contains(curNode.getType());
     }
 
+    @Override
+    public void destroy() {
+        super.destroy();
+        context.remove();
+        TREE_CACHE.remove();
+    }
+
     /**
      * The file context holder.
      */
