@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,10 +19,10 @@
 
 package com.puppycrawl.tools.checkstyle;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.File;
 import java.io.IOException;
@@ -36,7 +36,7 @@ import java.util.Enumeration;
 import java.util.HashSet;
 import java.util.Set;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.xml.sax.SAXException;
 
 import com.puppycrawl.tools.checkstyle.api.CheckstyleException;
@@ -60,8 +60,7 @@ public class PackageNamesLoaderTest extends AbstractPathTestSupport {
         final Set<String> packageNames = PackageNamesLoader
                 .getPackageNames(Thread.currentThread()
                         .getContextClassLoader());
-        assertEquals("pkgNames.length.", 0,
-                packageNames.size());
+        assertEquals(0, packageNames.size(), "pkgNames.length.");
     }
 
     @Test
@@ -69,7 +68,7 @@ public class PackageNamesLoaderTest extends AbstractPathTestSupport {
         final Set<String> actualPackageNames = PackageNamesLoader
                 .getPackageNames(new TestUrlsClassLoader(Collections.emptyEnumeration()));
 
-        assertEquals("Invalid package names length.", 0, actualPackageNames.size());
+        assertEquals(0, actualPackageNames.size(), "Invalid package names length.");
     }
 
     @Test
@@ -100,11 +99,11 @@ public class PackageNamesLoaderTest extends AbstractPathTestSupport {
             "com.puppycrawl.tools.checkstyle.filters",
         };
 
-        assertEquals("Invalid package names length.", expectedPackageNames.length,
-            actualPackageNames.size());
+        assertEquals(expectedPackageNames.length,
+            actualPackageNames.size(), "Invalid package names length.");
         final Set<String> checkstylePackagesSet =
                 new HashSet<>(Arrays.asList(expectedPackageNames));
-        assertEquals("Invalid names set.", checkstylePackagesSet, actualPackageNames);
+        assertEquals(checkstylePackagesSet, actualPackageNames, "Invalid names set.");
     }
 
     @Test
@@ -118,11 +117,11 @@ public class PackageNamesLoaderTest extends AbstractPathTestSupport {
             "coding.",
         };
 
-        assertEquals("Invalid package names length.", expectedPackageNames.length,
-            actualPackageNames.size());
+        assertEquals(expectedPackageNames.length,
+            actualPackageNames.size(), "Invalid package names length.");
         final Set<String> checkstylePackagesSet =
                 new HashSet<>(Arrays.asList(expectedPackageNames));
-        assertEquals("Invalid names set.", checkstylePackagesSet, actualPackageNames);
+        assertEquals(checkstylePackagesSet, actualPackageNames, "Invalid names set.");
     }
 
     @Test
@@ -137,11 +136,11 @@ public class PackageNamesLoaderTest extends AbstractPathTestSupport {
             "coding.",
         };
 
-        assertEquals("Invalid package names length.", expectedPackageNames.length,
-            actualPackageNames.size());
+        assertEquals(expectedPackageNames.length, actualPackageNames.size(),
+                "Invalid package names length.");
         final Set<String> checkstylePackagesSet =
                 new HashSet<>(Arrays.asList(expectedPackageNames));
-        assertEquals("Invalid names set.", checkstylePackagesSet, actualPackageNames);
+        assertEquals(checkstylePackagesSet, actualPackageNames, "Invalid names set.");
     }
 
     @Test
@@ -154,7 +153,7 @@ public class PackageNamesLoaderTest extends AbstractPathTestSupport {
             fail("CheckstyleException is expected");
         }
         catch (CheckstyleException ex) {
-            assertTrue("Invalid exception cause class", ex.getCause() instanceof SAXException);
+            assertTrue(ex.getCause() instanceof SAXException, "Invalid exception cause class");
         }
     }
 
@@ -185,9 +184,9 @@ public class PackageNamesLoaderTest extends AbstractPathTestSupport {
             fail("CheckstyleException is expected");
         }
         catch (CheckstyleException ex) {
-            assertTrue("Invalid exception cause class", ex.getCause() instanceof IOException);
-            assertNotEquals("Invalid exception message",
-                    "unable to get package file resources", ex.getMessage());
+            assertTrue(ex.getCause() instanceof IOException, "Invalid exception cause class");
+            assertNotEquals("unable to get package file resources", ex.getMessage(),
+                    "Invalid exception message");
         }
     }
 
@@ -198,9 +197,9 @@ public class PackageNamesLoaderTest extends AbstractPathTestSupport {
             fail("CheckstyleException is expected");
         }
         catch (CheckstyleException ex) {
-            assertTrue("Invalid exception cause class", ex.getCause() instanceof IOException);
-            assertEquals("Invalid exception message",
-                    "unable to get package file resources", ex.getMessage());
+            assertTrue(ex.getCause() instanceof IOException, "Invalid exception cause class");
+            assertEquals("unable to get package file resources", ex.getMessage(),
+                    "Invalid exception message");
         }
     }
 
