@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,9 +20,9 @@
 package com.puppycrawl.tools.checkstyle;
 
 import static com.puppycrawl.tools.checkstyle.checks.naming.AbstractNameCheck.MSG_INVALID_PATTERN;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.File;
 import java.io.Writer;
@@ -37,9 +37,8 @@ import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 import org.mockito.internal.util.Checks;
 import org.powermock.reflect.Whitebox;
 
@@ -66,8 +65,8 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
 
 public class TreeWalkerTest extends AbstractModuleTestSupport {
 
-    @Rule
-    public final TemporaryFolder temporaryFolder = new TemporaryFolder();
+    @TempDir
+    public File temporaryFolder;
 
     @Override
     protected String getPackageLocation() {
@@ -78,7 +77,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
     public void testProperFileExtension() throws Exception {
         final DefaultConfiguration checkConfig =
                 createModuleConfig(ConstantNameCheck.class);
-        final File file = temporaryFolder.newFile("file.java");
+        final File file = new File(temporaryFolder, "file.java");
         try (Writer writer = Files.newBufferedWriter(file.toPath(), StandardCharsets.UTF_8)) {
             final String content = "public class Main { public static final int k = 5 + 4; }";
             writer.write(content);
@@ -94,7 +93,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
     public void testImproperFileExtension() throws Exception {
         final DefaultConfiguration checkConfig =
                 createModuleConfig(ConstantNameCheck.class);
-        final File file = temporaryFolder.newFile("file.pdf");
+        final File file = new File(temporaryFolder, "file.pdf");
         try (Writer writer = Files.newBufferedWriter(file.toPath(), StandardCharsets.UTF_8)) {
             final String content = "public class Main { public static final int k = 5 + 4; }";
             writer.write(content);
@@ -124,14 +123,15 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
                     + " com.puppycrawl.tools.checkstyle.checks.coding.HiddenFieldCheck"));
 
             final Matcher errorMsgMatcher = expected.matcher(errorMsg);
-            assertTrue("Failure for: " + errorMsg, errorMsgMatcher.matches());
+            assertTrue(errorMsgMatcher.matches(), "Failure for: " + errorMsg);
         }
     }
 
     @Test
     public void testOnEmptyFile() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(HiddenFieldCheck.class);
-        final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
+        final String pathToEmptyFile =
+                File.createTempFile("file", ".java", temporaryFolder).getPath();
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
 
         verify(checkConfig, pathToEmptyFile, expected);
@@ -144,12 +144,12 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         try {
             final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
             verify(createChecker(checkConfig, ModuleCreationOption.IN_TREEWALKER),
-                    temporaryFolder.newFile().getPath(), expected);
+                    File.createTempFile("junit", null, temporaryFolder).getPath(), expected);
             fail("CheckstyleException is expected");
         }
         catch (CheckstyleException exception) {
-            assertTrue("Error message is unexpected",
-                    exception.getMessage().contains("TreeWalker is not allowed as a parent of"));
+            assertTrue(exception.getMessage().contains("TreeWalker is not allowed as a parent of"),
+                    "Error message is unexpected");
         }
     }
 
@@ -166,10 +166,9 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
             fail("Exception is expected");
         }
         catch (CheckstyleException ex) {
-            assertEquals("Error message is not expected",
-                    "TreeWalker is not allowed as a parent of java.lang.String Please review "
-                            + "'Parent Module' section for this Check in web documentation if "
-                            + "Check is standard.", ex.getMessage());
+            assertEquals("TreeWalker is not allowed as a parent of java.lang.String Please review "
+                    + "'Parent Module' section for this Check in web documentation if "
+                    + "Check is standard.", ex.getMessage(), "Error message is not expected");
         }
     }
 
@@ -180,16 +179,17 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         treeWalker.setTabWidth(1);
         treeWalker.configure(config);
 
-        assertEquals("Invalid setter result", 1,
-                (int) Whitebox.getInternalState(treeWalker, "tabWidth"));
-        assertEquals("Invalid configuration", config,
-            Whitebox.getInternalState(treeWalker, "configuration"));
+        final int tabWidth = Whitebox.getInternalState(treeWalker, "tabWidth");
+        assertEquals(1, tabWidth, "Invalid setter result");
+        final Object configuration = Whitebox.getInternalState(treeWalker, "configuration");
+        assertEquals(config, configuration, "Invalid configuration");
     }
 
     @Test
     public void testForInvalidCheckImplementation() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(BadJavaDocCheck.class);
-        final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
+        final String pathToEmptyFile =
+                File.createTempFile("file", ".java", temporaryFolder).getPath();
 
         try {
             final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
@@ -197,8 +197,8 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
             fail("Exception is expected");
         }
         catch (CheckstyleException ex) {
-            assertTrue("Error message is unexpected",
-                    ex.getMessage().contains("isCommentNodesRequired"));
+            assertTrue(ex.getMessage().contains("isCommentNodesRequired"),
+                    "Error message is unexpected");
         }
     }
 
@@ -222,9 +222,8 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
             fail("Exception expected");
         }
         catch (CheckstyleException ex) {
-            assertEquals("Invalid exception message",
-                "MismatchedTokenException occurred while parsing file input.java.",
-                ex.getMessage());
+            assertEquals("MismatchedTokenException occurred while parsing file input.java.",
+                ex.getMessage(), "Invalid exception message");
         }
     }
 
@@ -237,7 +236,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         final FileText fileText = new FileText(file, StandardCharsets.ISO_8859_1.name());
         treeWalker.processFiltered(file, fileText);
         final Collection<Checks> checks = Whitebox.getInternalState(treeWalker, "ordinaryChecks");
-        assertTrue("No checks -> No parsing", checks.isEmpty());
+        assertTrue(checks.isEmpty(), "No checks -> No parsing");
     }
 
     @Test
@@ -247,7 +246,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         final PackageObjectFactory factory = new PackageObjectFactory(
             new HashSet<>(), Thread.currentThread().getContextClassLoader());
         checker.setModuleFactory(factory);
-        final File file = temporaryFolder.newFile("file.java");
+        final File file = File.createTempFile("file", ".java", temporaryFolder);
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
 
         verify(checker, file.getPath(), expected);
@@ -261,7 +260,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
             new HashSet<>(), Thread.currentThread().getContextClassLoader());
         treeWalker.setModuleFactory(factory);
         treeWalker.setupChild(createModuleConfig(TypeNameCheck.class));
-        final File file = temporaryFolder.newFile("file.java");
+        final File file = new File(temporaryFolder, "file.java");
         final List<String> lines = new ArrayList<>();
         lines.add(" classD a {} ");
         final FileText fileText = new FileText(file, lines);
@@ -271,9 +270,8 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
             fail("Exception is expected");
         }
         catch (CheckstyleException exception) {
-            assertTrue("Error message is unexpected",
-                    exception.getMessage().contains(
-                    "occurred while parsing file"));
+            assertTrue(exception.getMessage().contains("occurred while parsing file"),
+                    "Error message is unexpected");
         }
     }
 
@@ -285,7 +283,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
             new HashSet<>(), Thread.currentThread().getContextClassLoader());
         treeWalker.setModuleFactory(factory);
         treeWalker.setupChild(createModuleConfig(TypeNameCheck.class));
-        final File file = temporaryFolder.newFile("file.java");
+        final File file = new File(temporaryFolder, "file.java");
         final List<String> lines = new ArrayList<>();
         lines.add(" class a%$# {} ");
         final FileText fileText = new FileText(file, lines);
@@ -295,9 +293,9 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
             fail("Exception is expected");
         }
         catch (CheckstyleException exception) {
-            assertTrue("Error message is unexpected",
-                    exception.getMessage().contains(
-                    "TokenStreamRecognitionException occurred while parsing file"));
+            assertTrue(exception.getMessage().contains(
+                    "TokenStreamRecognitionException occurred while parsing file"),
+                    "Error message is unexpected");
         }
     }
 
@@ -305,7 +303,8 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
     public void testRequiredTokenIsEmptyIntArray() throws Exception {
         final DefaultConfiguration checkConfig =
             createModuleConfig(RequiredTokenIsEmptyIntArray.class);
-        final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
+        final String pathToEmptyFile =
+                File.createTempFile("file", ".java", temporaryFolder).getPath();
 
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
         verify(checkConfig, pathToEmptyFile, expected);
@@ -318,12 +317,12 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
                 new HashSet<>(), Thread.currentThread().getContextClassLoader());
         treeWalker.setModuleFactory(factory);
         // create file that should throw exception
-        final File file = temporaryFolder.newFile("file.java");
+        final File file = new File(temporaryFolder, "file.java");
         final FileText fileText = new FileText(file, new ArrayList<>());
 
         treeWalker.processFiltered(file, fileText);
         final Collection<Checks> checks = Whitebox.getInternalState(treeWalker, "ordinaryChecks");
-        assertTrue("No checks -> No parsing", checks.isEmpty());
+        assertTrue(checks.isEmpty(), "No checks -> No parsing");
     }
 
     @Test
@@ -336,7 +335,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         treeWalker.setModuleFactory(factory);
         treeWalker.setupChild(createModuleConfig(TypeNameCheck.class));
         treeWalker.setupChild(createModuleConfig(CommentsIndentationCheck.class));
-        final File file = temporaryFolder.newFile("file.java");
+        final File file = new File(temporaryFolder, "file.java");
         final List<String> lines = new ArrayList<>();
         lines.add(" class a%$# {} ");
         final FileText fileText = new FileText(file, lines);
@@ -349,8 +348,8 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         catch (CheckstyleException exception) {
             final String message =
                     "TokenStreamRecognitionException occurred while parsing file";
-            assertTrue("Error message is unexpected",
-                    exception.getMessage().contains(message));
+            assertTrue(exception.getMessage().contains(message),
+                    "Error message is unexpected");
         }
     }
 
@@ -371,7 +370,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         final Set<TreeWalkerFilter> filters = Whitebox.getInternalState(treeWalker, "filters");
         final int tabWidth = Whitebox.getInternalState(filters.iterator().next(), "tabWidth");
 
-        assertEquals("expected tab width", 99, tabWidth);
+        assertEquals(99, tabWidth, "expected tab width");
     }
 
     @Test
@@ -410,20 +409,19 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         treeWalker.finishLocalSetup();
 
         final Context context = Whitebox.getInternalState(treeWalker, "childContext");
-        assertEquals("Severity differs from expected",
-                "error", context.get("severity"));
-        assertEquals("Tab width differs from expected",
-                String.valueOf(100), context.get("tabWidth"));
+        assertEquals("error", context.get("severity"), "Severity differs from expected");
+        assertEquals(String.valueOf(100), context.get("tabWidth"),
+                "Tab width differs from expected");
     }
 
     @Test
     public void testCheckInitIsCalledInTreeWalker() throws Exception {
         final DefaultConfiguration checkConfig =
                 createModuleConfig(VerifyInitCheck.class);
-        final File file = temporaryFolder.newFile("file.pdf");
+        final File file = File.createTempFile("file", ".pdf", temporaryFolder);
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
         verify(checkConfig, file.getPath(), expected);
-        assertTrue("Init was not called", VerifyInitCheck.isInitWasCalled());
+        assertTrue(VerifyInitCheck.isInitWasCalled(), "Init was not called");
     }
 
     @Test
@@ -431,10 +429,10 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         VerifyDestroyCheck.resetDestroyWasCalled();
         final DefaultConfiguration checkConfig =
                 createModuleConfig(VerifyDestroyCheck.class);
-        final File file = temporaryFolder.newFile("file.pdf");
+        final File file = File.createTempFile("file", ".pdf", temporaryFolder);
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
         verify(checkConfig, file.getPath(), expected);
-        assertTrue("Destroy was not called", VerifyDestroyCheck.isDestroyWasCalled());
+        assertTrue(VerifyDestroyCheck.isDestroyWasCalled(), "Destroy was not called");
     }
 
     @Test
@@ -442,10 +440,10 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         VerifyDestroyCheck.resetDestroyWasCalled();
         final DefaultConfiguration checkConfig =
                 createModuleConfig(VerifyDestroyCommentCheck.class);
-        final File file = temporaryFolder.newFile("file.pdf");
+        final File file = File.createTempFile("file", ".pdf", temporaryFolder);
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
         verify(checkConfig, file.getPath(), expected);
-        assertTrue("Destroy was not called", VerifyDestroyCheck.isDestroyWasCalled());
+        assertTrue(VerifyDestroyCheck.isDestroyWasCalled(), "Destroy was not called");
     }
 
     @Test
@@ -456,20 +454,19 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         treeWalkerConfig.addChild(filterConfig);
 
         final DefaultConfiguration checkerConfig = createRootConfig(treeWalkerConfig);
-        final File cacheFile = temporaryFolder.newFile();
+        final File cacheFile = File.createTempFile("junit", null, temporaryFolder);
         checkerConfig.addAttribute("cacheFile", cacheFile.getPath());
 
-        final String filePath = temporaryFolder.newFile("file.java").getPath();
+        final String filePath = File.createTempFile("file", ".java", temporaryFolder).getPath();
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
 
         verify(checkerConfig, filePath, expected);
         // One more time to use cache.
         verify(checkerConfig, filePath, expected);
 
-        assertTrue("External resource is not present in cache",
-                new String(Files.readAllBytes(cacheFile.toPath()),
-                        StandardCharsets.UTF_8).contains(
-                                "InputTreeWalkerSuppressionXpathFilter.xml"));
+        assertTrue(new String(Files.readAllBytes(cacheFile.toPath()), StandardCharsets.UTF_8)
+                        .contains("InputTreeWalkerSuppressionXpathFilter.xml"),
+                "External resource is not present in cache");
     }
 
     @Test
@@ -503,16 +500,16 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
         treeWalkerConfig.addChild(filterConfig);
 
         final DefaultConfiguration checkerConfig = createRootConfig(treeWalkerConfig);
-        final File cacheFile = temporaryFolder.newFile();
+        final File cacheFile = File.createTempFile("junit", null, temporaryFolder);
         checkerConfig.addAttribute("cacheFile", cacheFile.getPath());
 
-        final String filePath = temporaryFolder.newFile("file.java").getPath();
+        final String filePath = File.createTempFile("file", ".java", temporaryFolder).getPath();
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
 
         verify(checkerConfig, filePath, expected);
     }
 
-    private static class BadJavaDocCheck extends AbstractCheck {
+    public static class BadJavaDocCheck extends AbstractCheck {
 
         @Override
         public int[] getDefaultTokens() {
@@ -531,7 +528,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
 
     }
 
-    private static class VerifyInitCheck extends AbstractCheck {
+    public static class VerifyInitCheck extends AbstractCheck {
 
         private static boolean initWasCalled;
 
@@ -562,7 +559,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
 
     }
 
-    private static class VerifyDestroyCheck extends AbstractCheck {
+    public static class VerifyDestroyCheck extends AbstractCheck {
 
         private static boolean destroyWasCalled;
 
@@ -597,7 +594,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
 
     }
 
-    private static class VerifyDestroyCommentCheck extends VerifyDestroyCheck {
+    public static class VerifyDestroyCommentCheck extends VerifyDestroyCheck {
 
         @Override
         public boolean isCommentNodesRequired() {
@@ -606,7 +603,7 @@ public class TreeWalkerTest extends AbstractModuleTestSupport {
 
     }
 
-    private static class RequiredTokenIsEmptyIntArray extends AbstractCheck {
+    public static class RequiredTokenIsEmptyIntArray extends AbstractCheck {
 
         @Override
         public int[] getRequiredTokens() {
