@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,11 +19,11 @@
 
 package com.puppycrawl.tools.checkstyle.checks;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.File;
 import java.lang.reflect.Constructor;
@@ -33,8 +33,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 
-import org.junit.After;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Test;
 import org.powermock.reflect.Whitebox;
 
 import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
@@ -62,7 +62,7 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
         return "com/puppycrawl/tools/checkstyle/checks/suppresswarningsholder";
     }
 
-    @After
+    @AfterEach
     public void cleanUp() {
         // clear cache that may have been set by tests
 
@@ -77,10 +77,10 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
     public void testGet() {
         final SuppressWarningsHolder checkObj = new SuppressWarningsHolder();
         final int[] expected = {TokenTypes.ANNOTATION};
-        assertArrayEquals("Required token array differs from expected",
-                expected, checkObj.getRequiredTokens());
-        assertArrayEquals("Required token array differs from expected",
-                expected, checkObj.getAcceptableTokens());
+        assertArrayEquals(expected, checkObj.getRequiredTokens(),
+                "Required token array differs from expected");
+        assertArrayEquals(expected, checkObj.getAcceptableTokens(),
+                "Required token array differs from expected");
     }
 
     @Test
@@ -136,26 +136,25 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
 
     @Test
     public void testGetDefaultAlias() {
-        assertEquals("Default alias differs from expected",
-                "somename", SuppressWarningsHolder.getDefaultAlias("SomeName"));
-        assertEquals("Default alias differs from expected",
-                "somename", SuppressWarningsHolder.getDefaultAlias("SomeNameCheck"));
+        assertEquals("somename", SuppressWarningsHolder.getDefaultAlias("SomeName"),
+                "Default alias differs from expected");
+        assertEquals("somename", SuppressWarningsHolder.getDefaultAlias("SomeNameCheck"),
+                "Default alias differs from expected");
     }
 
     @Test
     public void testSetAliasListEmpty() {
         final SuppressWarningsHolder holder = new SuppressWarningsHolder();
         holder.setAliasList("");
-        assertEquals("Empty alias list should not be set", "",
-            SuppressWarningsHolder.getAlias(""));
+        assertEquals("", SuppressWarningsHolder.getAlias(""), "Empty alias list should not be set");
     }
 
     @Test
     public void testSetAliasListCorrect() {
         final SuppressWarningsHolder holder = new SuppressWarningsHolder();
         holder.setAliasList("alias=value");
-        assertEquals("Alias differs from expected",
-                "value", SuppressWarningsHolder.getAlias("alias"));
+        assertEquals("value", SuppressWarningsHolder.getAlias("alias"),
+                "Alias differs from expected");
     }
 
     @Test
@@ -167,8 +166,8 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
             fail("Exception expected");
         }
         catch (IllegalArgumentException ex) {
-            assertEquals("Error message is unexpected",
-                    "'=' expected in alias list item: =SomeAlias", ex.getMessage());
+            assertEquals("'=' expected in alias list item: =SomeAlias", ex.getMessage(),
+                    "Error message is unexpected");
         }
     }
 
@@ -177,7 +176,7 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
         populateHolder("MockEntry", 100, 100, 350, 350);
         final AuditEvent event = createAuditEvent("check", 100, 10);
 
-        assertFalse("Event is not suppressed", SuppressWarningsHolder.isSuppressed(event));
+        assertFalse(SuppressWarningsHolder.isSuppressed(event), "Event is not suppressed");
     }
 
     @Test
@@ -187,7 +186,7 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
         final AuditEvent event = createAuditEvent("id", 110, 10);
         holder.setAliasList(MemberNameCheck.class.getName() + "=check");
 
-        assertTrue("Event is not suppressed", SuppressWarningsHolder.isSuppressed(event));
+        assertTrue(SuppressWarningsHolder.isSuppressed(event), "Event is not suppressed");
     }
 
     @Test
@@ -195,7 +194,7 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
         populateHolder("check", 100, 100, 350, 350);
         final AuditEvent event = createAuditEvent("check", 350, 350);
 
-        assertTrue("Event is not suppressed", SuppressWarningsHolder.isSuppressed(event));
+        assertTrue(SuppressWarningsHolder.isSuppressed(event), "Event is not suppressed");
     }
 
     @Test
@@ -203,7 +202,7 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
         populateHolder("check", 100, 100, 350, 350);
         final AuditEvent event = createAuditEvent("check", 350, 352);
 
-        assertFalse("Event is not suppressed", SuppressWarningsHolder.isSuppressed(event));
+        assertFalse(SuppressWarningsHolder.isSuppressed(event), "Event is not suppressed");
     }
 
     @Test
@@ -211,7 +210,7 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
         populateHolder("check", 100, 100, 350, 350);
         final AuditEvent event = createAuditEvent("check", 400, 10);
 
-        assertFalse("Event is not suppressed", SuppressWarningsHolder.isSuppressed(event));
+        assertFalse(SuppressWarningsHolder.isSuppressed(event), "Event is not suppressed");
     }
 
     @Test
@@ -219,7 +218,7 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
         populateHolder("check", 100, 100, 350, 350);
         final AuditEvent event = createAuditEvent("check", 100, 100);
 
-        assertTrue("Event is not suppressed", SuppressWarningsHolder.isSuppressed(event));
+        assertTrue(SuppressWarningsHolder.isSuppressed(event), "Event is not suppressed");
     }
 
     @Test
@@ -231,22 +230,21 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
             new LocalizedMessage(100, 10, null, null, null, "id", MemberNameCheck.class, "msg");
         final AuditEvent firstEventForTest =
             new AuditEvent(source, "fileName", firstMessageForTest);
-        assertFalse("Event is suppressed",
-                SuppressWarningsHolder.isSuppressed(firstEventForTest));
+        assertFalse(SuppressWarningsHolder.isSuppressed(firstEventForTest), "Event is suppressed");
 
         final LocalizedMessage secondMessageForTest =
             new LocalizedMessage(100, 150, null, null, null, "id", MemberNameCheck.class, "msg");
         final AuditEvent secondEventForTest =
             new AuditEvent(source, "fileName", secondMessageForTest);
-        assertTrue("Event is not suppressed",
-                SuppressWarningsHolder.isSuppressed(secondEventForTest));
+        assertTrue(SuppressWarningsHolder.isSuppressed(secondEventForTest),
+                "Event is not suppressed");
 
         final LocalizedMessage thirdMessageForTest =
             new LocalizedMessage(200, 1, null, null, null, "id", MemberNameCheck.class, "msg");
         final AuditEvent thirdEventForTest =
             new AuditEvent(source, "fileName", thirdMessageForTest);
-        assertTrue("Event is not suppressed",
-                SuppressWarningsHolder.isSuppressed(thirdEventForTest));
+        assertTrue(SuppressWarningsHolder.isSuppressed(thirdEventForTest),
+                "Event is not suppressed");
     }
 
     @Test
@@ -294,10 +292,10 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
             fail("Exception expected");
         }
         catch (InvocationTargetException ex) {
-            assertTrue("Error type is unexpected",
-                    ex.getCause() instanceof IllegalArgumentException);
-            assertEquals("Error message is unexpected",
-                    "Unexpected AST: Method Def[0x0]", ex.getCause().getMessage());
+            assertTrue(ex.getCause() instanceof IllegalArgumentException,
+                    "Error type is unexpected");
+            assertEquals("Unexpected AST: Method Def[0x0]", ex.getCause().getMessage(),
+                    "Error message is unexpected");
         }
     }
 
@@ -319,11 +317,10 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
             fail("Exception expected");
         }
         catch (InvocationTargetException ex) {
-            assertTrue("Error type is unexpected",
-                    ex.getCause() instanceof IllegalArgumentException);
-            assertEquals("Error message is unexpected",
-                    "Expression or annotation array"
-                    + " initializer AST expected: Method Def[0x0]", ex.getCause().getMessage());
+            assertTrue(ex.getCause() instanceof IllegalArgumentException,
+                    "Error type is unexpected");
+            assertEquals("Expression or annotation array initializer AST expected: Method Def[0x0]",
+                    ex.getCause().getMessage(), "Error message is unexpected");
         }
     }
 
@@ -350,10 +347,10 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
             fail("Exception expected");
         }
         catch (InvocationTargetException ex) {
-            assertTrue("Error type is unexpected",
-                    ex.getCause() instanceof IllegalArgumentException);
-            assertEquals("Error message is unexpected",
-                    "Unexpected container AST: Parent ast[0x0]", ex.getCause().getMessage());
+            assertTrue(ex.getCause() instanceof IllegalArgumentException,
+                    "Error type is unexpected");
+            assertEquals("Unexpected container AST: Parent ast[0x0]", ex.getCause().getMessage(),
+                    "Error message is unexpected");
         }
     }
 
@@ -368,8 +365,8 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
             fail("Exception expected");
         }
         catch (IllegalArgumentException ex) {
-            assertEquals("Error message is unexpected",
-                    "Identifier AST expected, but get null.", ex.getMessage());
+            assertEquals("Identifier AST expected, but get null.", ex.getMessage(),
+                    "Error message is unexpected");
         }
     }
 
@@ -393,11 +390,12 @@ public class SuppressWarningsHolderTest extends AbstractModuleTestSupport {
                     JavaParser.Options.WITHOUT_COMMENTS),
             ast -> ast.getType() == TokenTypes.ANNOTATION);
 
-        assertTrue("Ast should contain ANNOTATION", annotationDef.isPresent());
-        assertTrue("State is not cleared on beginTree",
+        assertTrue(annotationDef.isPresent(), "Ast should contain ANNOTATION");
+        assertTrue(
             TestUtil.isStatefulFieldClearedDuringBeginTree(check, annotationDef.get(),
                 "ENTRIES",
-                entries -> ((ThreadLocal<List<Object>>) entries).get().isEmpty()));
+                entries -> ((ThreadLocal<List<Object>>) entries).get().isEmpty()),
+                "State is not cleared on beginTree");
     }
 
     private static void populateHolder(String checkName, int firstLine,
