@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -21,9 +21,10 @@ package com.puppycrawl.tools.checkstyle.checks.indentation;
 
 import static com.puppycrawl.tools.checkstyle.checks.indentation.CommentsIndentationCheck.MSG_KEY_BLOCK;
 import static com.puppycrawl.tools.checkstyle.checks.indentation.CommentsIndentationCheck.MSG_KEY_SINGLE;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.fail;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
@@ -213,12 +214,11 @@ public class CommentsIndentationCheckTest extends AbstractModuleTestSupport {
         methodDef.setText("methodStub");
         try {
             check.visitToken(methodDef);
-            Assert.fail("IllegalArgumentException should have been thrown!");
+            fail("IllegalArgumentException should have been thrown!");
         }
         catch (IllegalArgumentException ex) {
             final String msg = ex.getMessage();
-            Assert.assertEquals("Invalid exception message",
-                    "Unexpected token type: methodStub", msg);
+            assertEquals("Unexpected token type: methodStub", msg, "Invalid exception message");
         }
     }
 
