@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -26,18 +26,25 @@ import static com.puppycrawl.tools.checkstyle.checks.javadoc.AbstractJavadocChec
 import static com.puppycrawl.tools.checkstyle.checks.javadoc.SummaryJavadocCheck.MSG_SUMMARY_FIRST_SENTENCE;
 import static java.util.Arrays.asList;
 import static java.util.Collections.singletonList;
-import static org.junit.Assert.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.File;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 
-import org.junit.Assert;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.contrib.java.lang.system.SystemErrRule;
-import org.junit.rules.TemporaryFolder;
+import org.itsallcode.io.Capturable;
+import org.itsallcode.junit.sysextensions.SystemErrGuard;
+import org.itsallcode.junit.sysextensions.SystemErrGuard.SysErr;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.extension.ExtendWith;
+import org.junit.jupiter.api.io.TempDir;
 
 import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
 import com.puppycrawl.tools.checkstyle.DefaultConfiguration;
@@ -47,19 +54,30 @@ import com.puppycrawl.tools.checkstyle.api.JavadocTokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
 import com.puppycrawl.tools.checkstyle.utils.JavadocUtil;
 
+@ExtendWith(SystemErrGuard.class)
 public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
 
-    @Rule
-    public final SystemErrRule systemErr = new SystemErrRule().enableLog().mute();
-
-    @Rule
-    public final TemporaryFolder temporaryFolder = new TemporaryFolder();
+    @TempDir
+    public File temporaryFolder;
 
     @Override
     protected String getPackageLocation() {
         return "com/puppycrawl/tools/checkstyle/checks/javadoc/abstractjavadoc";
     }
 
+    /**
+     * <p>Configures the environment for each test.</p>
+     * <ul>
+     * <li>Start output capture for {@link System#err}</li>
+     * </ul>
+     *
+     * @param systemErr wrapper for {@code System.err}
+     */
+    @BeforeEach
+    public void setUp(@SysErr Capturable systemErr) {
+        systemErr.captureMuted();
+    }
+
     @Test
     public void testJavadocTagsWithoutArgs() throws Exception {
         final DefaultConfiguration checkconfig = createModuleConfig(TempCheck.class);
@@ -107,14 +125,14 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
     }
 
     @Test
-    public void testParsingErrors() throws Exception {
+    public void testParsingErrors(@SysErr Capturable systemErr) throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(TempCheck.class);
         final String[] expected = {
             "4: " + getCheckMessage(MSG_JAVADOC_MISSED_HTML_CLOSE, 4, "unclosedTag"),
             "8: " + getCheckMessage(MSG_JAVADOC_WRONG_SINGLETON_TAG, 35, "img"),
         };
         verify(checkConfig, getPath("InputAbstractJavadocParsingErrors.java"), expected);
-        assertEquals("Error is unexpected", "", systemErr.getLog());
+        assertEquals("", systemErr.getCapturedData(), "Error is unexpected");
     }
 
     @Test
@@ -129,18 +147,19 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
     }
 
     @Test
-    public void testAntlrError() throws Exception {
+    public void testAntlrError(@SysErr Capturable systemErr) throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(TempCheck.class);
         final String[] expected = {
             "4: " + getCheckMessage(MSG_JAVADOC_PARSE_RULE_ERROR, 78,
                     "mismatched input '(' expecting <EOF>", "JAVADOC"),
         };
         verify(checkConfig, getPath("InputAbstractJavadocInvalidAtSeeReference.java"), expected);
-        assertEquals("Error is unexpected", "", systemErr.getLog());
+        assertEquals("", systemErr.getCapturedData(), "Error is unexpected");
     }
 
     @Test
-    public void testCheckReuseAfterParseErrorWithFollowingAntlrErrorInTwoFiles() throws Exception {
+    public void testCheckReuseAfterParseErrorWithFollowingAntlrErrorInTwoFiles(
+            @SysErr Capturable systemErr) throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(TempCheck.class);
         final Map<String, List<String>> expectedMessages = new LinkedHashMap<>(2);
         expectedMessages.put(getPath("InputAbstractJavadocParsingErrors.java"), asList(
@@ -155,7 +174,7 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
             new File(getPath("InputAbstractJavadocParsingErrors.java")),
             new File(getPath("InputAbstractJavadocInvalidAtSeeReference.java")), },
                 expectedMessages);
-        assertEquals("Error is unexpected", "", systemErr.getLog());
+        assertEquals("", systemErr.getCapturedData(), "Error is unexpected");
     }
 
     @Test
@@ -178,8 +197,7 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
         final DefaultConfiguration checkConfig = createModuleConfig(JavadocCatchCheck.class);
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputAbstractJavadocPosition.java"), expected);
-        assertEquals("Invalid number of javadocs",
-            65, JavadocCatchCheck.javadocsNumber);
+        assertEquals(65, JavadocCatchCheck.javadocsNumber, "Invalid number of javadocs");
     }
 
     @Test
@@ -190,8 +208,7 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
         verify(checkConfig,
             getPath("InputAbstractJavadocPositionWithSinglelineComments.java"), expected);
-        assertEquals("Invalid number of javadocs",
-                65, JavadocCatchCheck.javadocsNumber);
+        assertEquals(65, JavadocCatchCheck.javadocsNumber, "Invalid number of javadocs");
     }
 
     @Test
@@ -201,8 +218,7 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
         final DefaultConfiguration checkConfig = createModuleConfig(JavadocCatchCheck.class);
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputAbstractJavadocPositionOnlyComments.java"), expected);
-        assertEquals("Invalid number of javadocs",
-                0, JavadocCatchCheck.javadocsNumber);
+        assertEquals(0, JavadocCatchCheck.javadocsNumber, "Invalid number of javadocs");
     }
 
     @Test
@@ -220,17 +236,17 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
             }
         };
 
-        Assert.assertNotNull("Default tokens should not be null", check.getDefaultTokens());
-        Assert.assertArrayEquals("Acceptable tokens should be equal to default",
-                check.getDefaultTokens(), check.getAcceptableTokens());
-        Assert.assertArrayEquals("Required tokens should be equal to default",
-                check.getDefaultTokens(), check.getRequiredTokens());
-        Assert.assertArrayEquals("Invalid default javadoc tokens",
-                defaultJavadocTokens, check.getDefaultJavadocTokens());
-        Assert.assertArrayEquals("Invalid acceptable javadoc tokens",
-                defaultJavadocTokens, check.getAcceptableJavadocTokens());
-        Assert.assertNotEquals("Invalid required javadoc tokens",
-                defaultJavadocTokens, check.getRequiredJavadocTokens());
+        assertNotNull(check.getDefaultTokens(), "Default tokens should not be null");
+        assertArrayEquals(check.getDefaultTokens(), check.getAcceptableTokens(),
+                "Acceptable tokens should be equal to default");
+        assertArrayEquals(check.getDefaultTokens(), check.getRequiredTokens(),
+                "Required tokens should be equal to default");
+        assertArrayEquals(defaultJavadocTokens, check.getDefaultJavadocTokens(),
+                "Invalid default javadoc tokens");
+        assertArrayEquals(defaultJavadocTokens, check.getAcceptableJavadocTokens(),
+                "Invalid acceptable javadoc tokens");
+        assertNotEquals(defaultJavadocTokens, check.getRequiredJavadocTokens(),
+                "Invalid required javadoc tokens");
     }
 
     @Test
@@ -242,14 +258,14 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
         try {
             final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
             verify(checkConfig, getPath("InputAbstractJavadocMain.java"), expected);
-            Assert.fail("CheckstyleException is expected");
+            fail("CheckstyleException is expected");
         }
         catch (IllegalStateException ex) {
             final String expected = "Javadoc Token "
                     + "\"RETURN_LITERAL\" was not found in "
                     + "Acceptable javadoc tokens list in check";
-            Assert.assertTrue("Invalid exception, should start with: " + expected,
-                    ex.getMessage().startsWith(expected));
+            assertTrue(ex.getMessage().startsWith(expected),
+                    "Invalid exception, should start with: " + expected);
         }
     }
 
@@ -268,19 +284,20 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
     public void testRequiredTokenIsNotInDefaultTokens() throws Exception {
         final DefaultConfiguration checkConfig =
             createModuleConfig(RequiredTokenIsNotInDefaultsJavadocCheck.class);
-        final String pathToEmptyFile = temporaryFolder.newFile("file.java").getPath();
+        final String pathToEmptyFile =
+                File.createTempFile("empty", ".java", temporaryFolder).getPath();
 
         try {
             final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
             verify(checkConfig, pathToEmptyFile, expected);
-            Assert.fail("CheckstyleException is expected");
+            fail("CheckstyleException is expected");
         }
         catch (IllegalStateException ex) {
             final String expected = "Javadoc Token \""
                     + JavadocTokenTypes.RETURN_LITERAL + "\" from required"
                     + " javadoc tokens was not found in default javadoc tokens list in check";
-            Assert.assertTrue("Invalid exception, should start with: " + expected,
-                    ex.getMessage().startsWith(expected));
+            assertTrue(ex.getMessage().startsWith(expected),
+                    "Invalid exception, should start with: " + expected);
         }
     }
 
@@ -291,10 +308,10 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
         final DefaultConfiguration checkConfig = createModuleConfig(JavadocVisitLeaveCheck.class);
         final String[] expected = CommonUtil.EMPTY_STRING_ARRAY;
         verify(checkConfig, getPath("InputAbstractJavadocPosition.java"), expected);
-        Assert.assertTrue("Javadoc visit count should be greater than zero",
-                JavadocVisitLeaveCheck.visitCount > 0);
-        assertEquals("Javadoc visit and leave count should be equal",
-                JavadocVisitLeaveCheck.visitCount, JavadocVisitLeaveCheck.leaveCount);
+        assertTrue(JavadocVisitLeaveCheck.visitCount > 0,
+                "Javadoc visit count should be greater than zero");
+        assertEquals(JavadocVisitLeaveCheck.visitCount, JavadocVisitLeaveCheck.leaveCount,
+                "Javadoc visit and leave count should be equal");
     }
 
     @Test
@@ -449,7 +466,7 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
         verify(checkConfig, getPath("InputAbstractJavadocNonTightHtmlTags2.java"), expected);
     }
 
-    private static class TempCheck extends AbstractJavadocCheck {
+    public static class TempCheck extends AbstractJavadocCheck {
 
         @Override
         public int[] getDefaultJavadocTokens() {
@@ -463,7 +480,7 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
 
     }
 
-    private static class JavadocCatchCheck extends AbstractJavadocCheck {
+    public static class JavadocCatchCheck extends AbstractJavadocCheck {
 
         private static int javadocsNumber;
 
@@ -478,16 +495,16 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
 
         @Override
         public void visitJavadocToken(DetailNode ast) {
-            assertEquals(ast.toString(), "JAVADOC", ast.getText());
+            assertEquals("JAVADOC", ast.getText(), ast.toString());
             final DetailNode text = JavadocUtil.findFirstToken(ast, JavadocTokenTypes.TEXT);
-            Assert.assertNotNull("Empty javadoc text at " + ast, text);
-            assertEquals(ast.toString(), "Javadoc", text.getText());
+            assertNotNull(text, "Empty javadoc text at " + ast);
+            assertEquals("Javadoc", text.getText(), ast.toString());
             javadocsNumber++;
         }
 
     }
 
-    private static class RequiredTokenIsNotInDefaultsJavadocCheck extends AbstractJavadocCheck {
+    public static class RequiredTokenIsNotInDefaultsJavadocCheck extends AbstractJavadocCheck {
 
         @Override
         public int[] getRequiredJavadocTokens() {
@@ -511,7 +528,7 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
 
     }
 
-    private static class TokenIsNotInAcceptablesJavadocCheck extends AbstractJavadocCheck {
+    public static class TokenIsNotInAcceptablesJavadocCheck extends AbstractJavadocCheck {
 
         @Override
         public int[] getRequiredJavadocTokens() {
@@ -535,7 +552,7 @@ public class AbstractJavadocCheckTest extends AbstractModuleTestSupport {
 
     }
 
-    private static class JavadocVisitLeaveCheck extends AbstractJavadocCheck {
+    public static class JavadocVisitLeaveCheck extends AbstractJavadocCheck {
 
         private static int visitCount;
         private static int leaveCount;
