@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,12 +20,12 @@
 package com.puppycrawl.tools.checkstyle.checks.metrics;
 
 import static com.puppycrawl.tools.checkstyle.checks.metrics.ClassDataAbstractionCouplingCheck.MSG_KEY;
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.fail;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import antlr.CommonHiddenStreamToken;
 import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
@@ -45,12 +45,12 @@ public class ClassDataAbstractionCouplingCheckTest extends AbstractModuleTestSup
     @Test
     public void testTokens() {
         final ClassDataAbstractionCouplingCheck check = new ClassDataAbstractionCouplingCheck();
-        assertNotNull("Required tokens should not be null", check.getRequiredTokens());
-        assertNotNull("Acceptable tokens should not be null", check.getAcceptableTokens());
-        assertArrayEquals("Invalid default tokens", check.getDefaultTokens(),
-                check.getAcceptableTokens());
-        assertArrayEquals("Invalid acceptable tokens", check.getDefaultTokens(),
-                check.getRequiredTokens());
+        assertNotNull(check.getRequiredTokens(), "Required tokens should not be null");
+        assertNotNull(check.getAcceptableTokens(), "Acceptable tokens should not be null");
+        assertArrayEquals(check.getDefaultTokens(),
+                check.getAcceptableTokens(), "Invalid default tokens");
+        assertArrayEquals(check.getDefaultTokens(),
+                check.getRequiredTokens(), "Invalid acceptable tokens");
     }
 
     @Test
@@ -123,17 +123,16 @@ public class ClassDataAbstractionCouplingCheckTest extends AbstractModuleTestSup
             fail("exception expected");
         }
         catch (CheckstyleException ex) {
-            assertEquals("Invalid exception message",
-                "cannot initialize module com.puppycrawl.tools.checkstyle.TreeWalker - "
+            assertEquals("cannot initialize module com.puppycrawl.tools.checkstyle.TreeWalker - "
                     + "cannot initialize module com.puppycrawl.tools.checkstyle.checks."
                     + "metrics.ClassDataAbstractionCouplingCheck - "
                     + "Cannot set property 'excludedPackages' to "
                     + "'com.puppycrawl.tools.checkstyle.checks.metrics.inputs.a.'",
-                ex.getMessage());
-            assertEquals("Invalid exception message,",
-                    "the following values are not valid identifiers: ["
-                            + "com.puppycrawl.tools.checkstyle.checks.metrics.inputs.a.]", ex
-                            .getCause().getCause().getCause().getCause().getMessage());
+                ex.getMessage(), "Invalid exception message");
+            assertEquals("the following values are not valid identifiers: ["
+                    + "com.puppycrawl.tools.checkstyle.checks.metrics.inputs.a.]", ex
+                    .getCause().getCause().getCause().getCause().getMessage(),
+                    "Invalid exception message,");
         }
     }
 
@@ -179,8 +178,7 @@ public class ClassDataAbstractionCouplingCheckTest extends AbstractModuleTestSup
             fail("exception expected");
         }
         catch (IllegalArgumentException ex) {
-            assertEquals("Invalid exception message",
-                "Unknown type: ctor[0x-1]", ex.getMessage());
+            assertEquals("Unknown type: ctor[0x-1]", ex.getMessage(), "Invalid exception message");
         }
     }
 
