@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,13 +20,13 @@
 package com.puppycrawl.tools.checkstyle.checks.sizes;
 
 import static com.puppycrawl.tools.checkstyle.checks.sizes.ExecutableStatementCountCheck.MSG_KEY;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.util.Collection;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import antlr.CommonHiddenStreamToken;
 import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
@@ -51,9 +51,10 @@ public class ExecutableStatementCountCheckTest
         final DetailAstImpl ast = new DetailAstImpl();
         ast.setType(TokenTypes.STATIC_INIT);
         final ExecutableStatementCountCheck check = new ExecutableStatementCountCheck();
-        Assert.assertTrue("Stateful field is not cleared after beginTree",
+        assertTrue(
                 TestUtil.isStatefulFieldClearedDuringBeginTree(check, ast, "contextStack",
-                    contextStack -> ((Collection<Context>) contextStack).isEmpty()));
+                    contextStack -> ((Collection<Context>) contextStack).isEmpty()),
+                "Stateful field is not cleared after beginTree");
     }
 
     @Test
@@ -157,7 +158,7 @@ public class ExecutableStatementCountCheckTest
             fail("exception expected");
         }
         catch (IllegalStateException ex) {
-            assertEquals("Invalid exception message", "ENUM[0x-1]", ex.getMessage());
+            assertEquals("ENUM[0x-1]", ex.getMessage(), "Invalid exception message");
         }
     }
 
@@ -173,7 +174,7 @@ public class ExecutableStatementCountCheckTest
             fail("exception expected");
         }
         catch (IllegalStateException ex) {
-            assertEquals("Invalid exception message", "ENUM[0x-1]", ex.getMessage());
+            assertEquals("ENUM[0x-1]", ex.getMessage(), "Invalid exception message");
         }
     }
 
