@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,9 +20,9 @@
 package com.puppycrawl.tools.checkstyle.filters;
 
 import static com.puppycrawl.tools.checkstyle.checks.naming.AbstractNameCheck.MSG_INVALID_PATTERN;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.File;
 import java.util.Arrays;
@@ -31,7 +31,7 @@ import java.util.Collections;
 import java.util.List;
 import java.util.stream.Collectors;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.powermock.reflect.Whitebox;
 
 import com.puppycrawl.tools.checkstyle.AbstractModuleTestSupport;
@@ -307,7 +307,7 @@ public class SuppressWithNearbyCommentFilterTest
                 getTagsAfterExecution(filter, "filename", "//SUPPRESS CHECKSTYLE ignore").get(0);
         final EqualsVerifierReport ev = EqualsVerifier
                 .forClass(tag.getClass()).usingGetClass().report();
-        assertEquals("Error: " + ev.getMessage(), EqualsVerifierReport.SUCCESS, ev);
+        assertEquals(EqualsVerifierReport.SUCCESS, ev, "Error: " + ev.getMessage());
     }
 
     private void verifySuppressed(Configuration moduleConfig,
@@ -362,8 +362,9 @@ public class SuppressWithNearbyCommentFilterTest
         }
         catch (CheckstyleException ex) {
             final IllegalArgumentException cause = (IllegalArgumentException) ex.getCause();
-            assertEquals("Invalid exception message", "unable to parse influence"
-                + " from 'SUPPRESS CHECKSTYLE MemberNameCheck' using a", cause.getMessage());
+            assertEquals("unable to parse influence"
+                + " from 'SUPPRESS CHECKSTYLE MemberNameCheck' using a", cause.getMessage(),
+                    "Invalid exception message");
         }
     }
 
@@ -415,8 +416,8 @@ public class SuppressWithNearbyCommentFilterTest
         }
         catch (CheckstyleException ex) {
             final IllegalArgumentException cause = (IllegalArgumentException) ex.getCause();
-            assertEquals("Invalid exception message",
-                "unable to parse expanded comment a[l", cause.getMessage());
+            assertEquals("unable to parse expanded comment a[l", cause.getMessage(),
+                    "Invalid exception message");
         }
     }
 
@@ -428,7 +429,7 @@ public class SuppressWithNearbyCommentFilterTest
         contents.reportSingleLineComment(1, 0);
         final TreeWalkerAuditEvent auditEvent =
                 new TreeWalkerAuditEvent(contents, null, null, null);
-        assertTrue("Filter should accept null localized message", filter.accept(auditEvent));
+        assertTrue(filter.accept(auditEvent), "Filter should accept null localized message");
     }
 
     @Test
@@ -437,7 +438,7 @@ public class SuppressWithNearbyCommentFilterTest
         final FileContents contents = null;
         final TreeWalkerAuditEvent auditEvent = new TreeWalkerAuditEvent(contents, null,
                 new LocalizedMessage(1, null, null, null, null, Object.class, null), null);
-        assertTrue("Filter should accept audit event", filter.accept(auditEvent));
+        assertTrue(filter.accept(auditEvent), "Filter should accept audit event");
     }
 
     @Test
@@ -445,10 +446,10 @@ public class SuppressWithNearbyCommentFilterTest
         final SuppressWithNearbyCommentFilter filter = new SuppressWithNearbyCommentFilter();
         final Object tag =
                 getTagsAfterExecution(filter, "filename", "//SUPPRESS CHECKSTYLE ignore").get(0);
-        assertEquals("Invalid toString result",
-            "Tag[text='SUPPRESS CHECKSTYLE ignore', firstLine=1, lastLine=1, "
+        assertEquals(
+                "Tag[text='SUPPRESS CHECKSTYLE ignore', firstLine=1, lastLine=1, "
                     + "tagCheckRegexp=.*, tagMessageRegexp=null, tagIdRegexp=null]",
-                    tag.toString());
+                    tag.toString(), "Invalid toString result");
     }
 
     @Test
@@ -457,10 +458,10 @@ public class SuppressWithNearbyCommentFilterTest
         filter.setIdFormat(".*");
         final Object tag =
                 getTagsAfterExecution(filter, "filename", "//SUPPRESS CHECKSTYLE ignore").get(0);
-        assertEquals("Invalid toString result",
-            "Tag[text='SUPPRESS CHECKSTYLE ignore', firstLine=1, lastLine=1, "
+        assertEquals(
+                "Tag[text='SUPPRESS CHECKSTYLE ignore', firstLine=1, lastLine=1, "
                     + "tagCheckRegexp=.*, tagMessageRegexp=null, tagIdRegexp=.*]",
-                    tag.toString());
+                    tag.toString(), "Invalid toString result");
     }
 
     @Test
@@ -726,10 +727,10 @@ public class SuppressWithNearbyCommentFilterTest
                 new SuppressWithNearbyCommentFilter();
         final List<?> tags1 = getTagsAfterExecution(suppressionCommentFilter,
                 "filename1", "//SUPPRESS CHECKSTYLE ignore this");
-        assertEquals("Invalid tags size", 1, tags1.size());
+        assertEquals(1, tags1.size(), "Invalid tags size");
         final List<?> tags2 = getTagsAfterExecution(suppressionCommentFilter,
                 "filename2", "No comments in this file");
-        assertEquals("Invalid tags size", 0, tags2.size());
+        assertEquals(0, tags2.size(), "Invalid tags size");
     }
 
     /**
