@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -19,10 +19,10 @@
 
 package com.puppycrawl.tools.checkstyle.grammar;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 import java.io.InputStream;
@@ -32,7 +32,7 @@ import java.lang.reflect.Method;
 import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import antlr.NoViableAltForCharException;
 import antlr.ParserSharedInputState;
@@ -68,6 +68,12 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
                 getPath("InputRegressionJava8Class1.java"));
     }
 
+    @Test
+    public void testJava8ClassAstTree2() throws Exception {
+        verifyAst(getPath("InputRegressionJava8Class2Ast.txt"),
+                getPath("InputRegressionJava8Class2.java"));
+    }
+
     @Test
     public void testInputSemicolonBetweenImports() throws Exception {
         verifyAst(getPath("InputSemicolonBetweenImportsAst.txt"),
@@ -121,8 +127,8 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
         final Class<?> clss = GeneratedJavaLexer.class;
         final Constructor<?> constructor = clss.getDeclaredConstructor(InputStream.class);
 
-        assertNotNull("InputStream should not be null",
-                constructor.newInstance(new Object[] {null}));
+        assertNotNull(constructor.newInstance(new Object[] {null}),
+                "InputStream should not be null");
     }
 
     @Test
@@ -131,8 +137,8 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
         final Constructor<?> constructor = clss
                 .getDeclaredConstructor(ParserSharedInputState.class);
 
-        assertNotNull("ParserSharedInputState should not be null",
-                constructor.newInstance(new Object[] {null}));
+        assertNotNull(constructor.newInstance(new Object[] {null}),
+                "ParserSharedInputState should not be null");
     }
 
     @Test
@@ -140,8 +146,8 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
         final Class<?> clss = GeneratedJavaRecognizer.class;
         final Constructor<?> constructor = clss.getDeclaredConstructor(TokenBuffer.class);
 
-        assertNotNull("TokenBuffer should not be null",
-                constructor.newInstance(new Object[] {null}));
+        assertNotNull(constructor.newInstance(new Object[] {null}),
+                "TokenBuffer should not be null");
     }
 
     @Test
@@ -239,8 +245,8 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
         final String actualContents = AstTreeStringPrinter.printAst(actualFileContents,
                 withComments);
 
-        assertEquals("Generated AST from Java code should match pre-defined AST", expectedContents,
-                actualContents);
+        assertEquals(expectedContents, actualContents,
+                "Generated AST from Java code should match pre-defined AST");
     }
 
     private static final class AssertGeneratedJavaLexer extends GeneratedJavaLexer {
@@ -294,12 +300,12 @@ public class AstRegressionTest extends AbstractTreeTestSupport {
             }
 
             if (expectPass) {
-                assertFalse("Call to GeneratedJavaLexer." + methodName
-                        + " resulted in an exception", exception);
+                assertFalse(exception, "Call to GeneratedJavaLexer." + methodName
+                        + " resulted in an exception");
             }
             else {
-                assertTrue("Call to GeneratedJavaLexer." + methodName
-                        + " did not result in an exception", exception);
+                assertTrue(exception, "Call to GeneratedJavaLexer." + methodName
+                        + " did not result in an exception");
             }
         }
 
