@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,7 +20,9 @@
 package com.puppycrawl.tools.checkstyle.internal;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
-import static org.junit.Assert.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.File;
 import java.nio.file.Files;
@@ -33,9 +35,8 @@ import java.util.regex.Pattern;
 
 import javax.xml.parsers.ParserConfigurationException;
 
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.w3c.dom.Document;
 import org.w3c.dom.NamedNodeMap;
 import org.w3c.dom.Node;
@@ -72,7 +73,7 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
         return "com.puppycrawl.tools.checkstyle.internal";
     }
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         final DefaultConfiguration checkConfig = new DefaultConfiguration(
                 JavaDocCapture.class.getName());
@@ -101,8 +102,7 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
 
             for (int position = 0; position < sources.getLength(); position++) {
                 final Node section = sources.item(position);
-                final String sectionName = section.getAttributes().getNamedItem("name")
-                        .getNodeValue();
+                final String sectionName = XmlUtil.getNameAttributeOfNode(section);
 
                 if ("Content".equals(sectionName) || "Overview".equals(sectionName)) {
                     continue;
@@ -148,8 +148,7 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
                 continue;
             }
 
-            final String subSectionName = subSection.getAttributes().getNamedItem("name")
-                    .getNodeValue();
+            final String subSectionName = XmlUtil.getNameAttributeOfNode(subSection);
 
             examineCheckSubSection(subSection, subSectionName);
         }
@@ -302,7 +301,7 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
         }
 
         if (sanitize) {
-            result.append(sanitizeXml(node.getTextContent()));
+            result.append(XmlUtil.sanitizeXml(node.getTextContent()));
         }
         else {
             result.append(getNodeText(node));
@@ -370,8 +369,8 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
             if ("a".equals(nodeName) && "href".equals(attrName)) {
                 String value = attribute.getNodeValue();
 
-                assertNotEquals("links starting with '#' aren't supported: " + value,
-                        '#', value.charAt(0));
+                assertNotEquals('#', value.charAt(0),
+                        "links starting with '#' aren't supported: " + value);
 
                 if (value.contains("://")) {
                     attrValue = value;
@@ -397,12 +396,7 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
         return result.toString();
     }
 
-    private static String sanitizeXml(String nodeValue) {
-        return nodeValue.replaceAll("^[\\r\\n\\s]+", "").replaceAll("[\\r\\n\\s]+$", "")
-                .replace("<", "&lt;").replace(">", "&gt;");
-    }
-
-    private static class JavaDocCapture extends AbstractCheck {
+    public static class JavaDocCapture extends AbstractCheck {
         private static final Pattern SETTER_PATTERN = Pattern.compile("^set[A-Z].*");
 
         @Override
@@ -448,7 +442,7 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
                         // ignore
                         break;
                     default:
-                        Assert.fail("Unknown token '" + TokenUtil.getTokenName(parentNode.getType())
+                        fail("Unknown token '" + TokenUtil.getTokenName(parentNode.getType())
                                 + "': " + ast.getLineNo());
                         break;
                 }
@@ -469,14 +463,13 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
 
         private static void visitClass(DetailAST node) {
             if (ScopeUtil.isInScope(node, Scope.PUBLIC)) {
-                Assert.assertEquals(
-                        checkName + "'s class-level JavaDoc",
-                        CHECK_TEXT.get("Description")
-                                + CHECK_TEXT.computeIfAbsent("Rule Description", unused -> "")
-                                + CHECK_TEXT.computeIfAbsent("Notes", unused -> "")
-                                + CHECK_TEXT.computeIfAbsent("Properties", unused -> "")
-                                + CHECK_TEXT.get("Examples") + " @since "
-                                + CHECK_TEXT.get("since"), getJavaDocText(node));
+                assertEquals(CHECK_TEXT.get("Description")
+                        + CHECK_TEXT.computeIfAbsent("Rule Description", unused -> "")
+                        + CHECK_TEXT.computeIfAbsent("Notes", unused -> "")
+                        + CHECK_TEXT.computeIfAbsent("Properties", unused -> "")
+                        + CHECK_TEXT.get("Examples") + " @since "
+                        + CHECK_TEXT.get("since"), getJavaDocText(node),
+                        checkName + "'s class-level JavaDoc");
             }
         }
 
@@ -486,9 +479,8 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
                 final String propertyDoc = CHECK_PROPERTY_DOC.get(propertyName);
 
                 if (propertyDoc != null) {
-                    Assert.assertEquals(checkName + "'s class field-level JavaDoc for "
-                                    + propertyName, makeFirstUpper(propertyDoc),
-                            getJavaDocText(node));
+                    assertEquals(makeFirstUpper(propertyDoc), getJavaDocText(node),
+                            checkName + "'s class field-level JavaDoc for " + propertyName);
                 }
             }
         }
@@ -503,10 +495,9 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
                 if (propertyDoc != null) {
                     final String javaDoc = getJavaDocText(node);
 
-                    Assert.assertEquals(checkName + "'s class method-level JavaDoc for "
-                            + propertyName,
-                            "Setter to " + makeFirstLower(propertyDoc),
-                            javaDoc.substring(0, javaDoc.indexOf(" @param")));
+                    assertEquals("Setter to " + makeFirstLower(propertyDoc),
+                            javaDoc.substring(0, javaDoc.indexOf(" @param")),
+                            checkName + "'s class method-level JavaDoc for " + propertyName);
                 }
             }
         }
@@ -551,7 +542,7 @@ public class XdocsJavaDocsTest extends AbstractModuleTestSupport {
                         .replace("\r", "");
             }
             catch (ParserConfigurationException ex) {
-                Assert.fail("Exception: " + ex.getClass() + " - " + ex.getMessage());
+                fail("Exception: " + ex.getClass() + " - " + ex.getMessage());
             }
 
             return result;
