@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2019 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -20,15 +20,15 @@
 package com.puppycrawl.tools.checkstyle.xpath;
 
 import static com.puppycrawl.tools.checkstyle.internal.utils.XpathUtil.getXpathItems;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.io.File;
 import java.util.List;
 
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import com.puppycrawl.tools.checkstyle.AbstractPathTestSupport;
 import com.puppycrawl.tools.checkstyle.DetailAstImpl;
@@ -51,7 +51,7 @@ public class ElementNodeTest extends AbstractPathTestSupport {
         return "com/puppycrawl/tools/checkstyle/xpath/xpathmapper";
     }
 
-    @Before
+    @BeforeEach
     public void init() throws Exception {
         final File file = new File(getPath("InputXpathMapperAst.java"));
         final DetailAST rootAst = JavaParser.parseFile(file, JavaParser.Options.WITHOUT_COMMENTS);
@@ -62,45 +62,45 @@ public class ElementNodeTest extends AbstractPathTestSupport {
     public void testGetParent() throws Exception {
         final String xpath = "//OBJBLOCK";
         final List<NodeInfo> nodes = getXpathItems(xpath, rootNode);
-        assertEquals("Invalid number of nodes", 1, nodes.size());
+        assertEquals(1, nodes.size(), "Invalid number of nodes");
         final AbstractNode parent = (AbstractNode) nodes.get(0).getParent();
-        assertEquals("Invalid token type", TokenTypes.CLASS_DEF, parent.getTokenType());
+        assertEquals(TokenTypes.CLASS_DEF, parent.getTokenType(), "Invalid token type");
     }
 
     @Test
     public void testRootOfElementNode() throws Exception {
         final String xpath = "//OBJBLOCK";
         final List<NodeInfo> nodes = getXpathItems(xpath, rootNode);
-        assertEquals("Invalid number of nodes", 1, nodes.size());
+        assertEquals(1, nodes.size(), "Invalid number of nodes");
         final AbstractNode root = (AbstractNode) nodes.get(0).getRoot();
-        assertEquals("Invalid token type", TokenTypes.EOF, root.getTokenType());
-        assertTrue("Should return true, because selected node is RootNode",
-                root instanceof RootNode);
+        assertEquals(TokenTypes.EOF, root.getTokenType(), "Invalid token type");
+        assertTrue(root instanceof RootNode,
+                "Should return true, because selected node is RootNode");
     }
 
     @Test
     public void testGetNodeByValueNumInt() throws Exception {
         final String xPath = "//NUM_INT[@text = 123]";
         final List<NodeInfo> nodes = getXpathItems(xPath, rootNode);
-        assertEquals("Invalid number of nodes", 1, nodes.size());
-        assertEquals("Invalid token type", TokenTypes.NUM_INT,
-                ((AbstractNode) nodes.get(0)).getTokenType());
+        assertEquals(1, nodes.size(), "Invalid number of nodes");
+        final int tokenType = ((AbstractNode) nodes.get(0)).getTokenType();
+        assertEquals(TokenTypes.NUM_INT, tokenType, "Invalid token type");
     }
 
     @Test
     public void testGetNodeByValueStringLiteral() throws Exception {
         final String xPath = "//STRING_LITERAL[@text = 'HelloWorld']";
         final List<NodeInfo> nodes = getXpathItems(xPath, rootNode);
-        assertEquals("Invalid number of nodes", 2, nodes.size());
-        assertEquals("Invalid token type", TokenTypes.STRING_LITERAL,
-                ((AbstractNode) nodes.get(0)).getTokenType());
+        assertEquals(2, nodes.size(), "Invalid number of nodes");
+        final int tokenType = ((AbstractNode) nodes.get(0)).getTokenType();
+        assertEquals(TokenTypes.STRING_LITERAL, tokenType, "Invalid token type");
     }
 
     @Test
     public void testGetNodeByValueWithSameTokenText() throws Exception {
         final String xPath = "//MODIFIERS[@text = 'MODIFIERS']";
         final List<NodeInfo> nodes = getXpathItems(xPath, rootNode);
-        assertEquals("Invalid number of nodes", 0, nodes.size());
+        assertEquals(0, nodes.size(), "Invalid number of nodes");
     }
 
     @Test
@@ -111,8 +111,8 @@ public class ElementNodeTest extends AbstractPathTestSupport {
 
         final ElementNode elementNode = new ElementNode(rootNode, rootNode, detailAST);
 
-        assertEquals("Invalid text attribute", "HelloWorld",
-                elementNode.getAttributeValue(null, "text"));
+        assertEquals("HelloWorld", elementNode.getAttributeValue(null, "text"),
+                "Invalid text attribute");
     }
 
     @Test
@@ -123,7 +123,7 @@ public class ElementNodeTest extends AbstractPathTestSupport {
 
         final ElementNode elementNode = new ElementNode(rootNode, rootNode, detailAST);
 
-        assertNull("Must be null", elementNode.getAttributeValue(null, "text"));
+        assertNull(elementNode.getAttributeValue(null, "text"), "Must be null");
     }
 
     @Test
@@ -134,7 +134,7 @@ public class ElementNodeTest extends AbstractPathTestSupport {
 
         final ElementNode elementNode = new ElementNode(rootNode, rootNode, detailAST);
 
-        assertNull("Must be null", elementNode.getAttributeValue(null, "somename"));
+        assertNull(elementNode.getAttributeValue(null, "somename"), "Must be null");
     }
 
     @Test
@@ -143,10 +143,10 @@ public class ElementNodeTest extends AbstractPathTestSupport {
         detailAST.setType(TokenTypes.METHOD_DEF);
         final ElementNode elementNode = new ElementNode(rootNode, rootNode, detailAST);
         try (AxisIterator iterator = elementNode.iterateAxis(AxisInfo.CHILD)) {
-            assertTrue("Invalid iterator", iterator instanceof EmptyIterator);
+            assertTrue(iterator instanceof EmptyIterator, "Invalid iterator");
         }
         try (AxisIterator iterator = elementNode.iterateAxis(AxisInfo.DESCENDANT)) {
-            assertTrue("Invalid iterator", iterator instanceof EmptyIterator);
+            assertTrue(iterator instanceof EmptyIterator, "Invalid iterator");
         }
     }
 
@@ -159,10 +159,10 @@ public class ElementNodeTest extends AbstractPathTestSupport {
         detailAST.addChild(childAst);
         final ElementNode elementNode = new ElementNode(rootNode, rootNode, detailAST);
         try (AxisIterator iterator = elementNode.iterateAxis(AxisInfo.CHILD)) {
-            assertTrue("Invalid iterator", iterator instanceof ArrayIterator);
+            assertTrue(iterator instanceof ArrayIterator, "Invalid iterator");
         }
         try (AxisIterator iterator = elementNode.iterateAxis(AxisInfo.DESCENDANT)) {
-            assertTrue("Invalid iterator", iterator instanceof Navigator.DescendantEnumeration);
+            assertTrue(iterator instanceof Navigator.DescendantEnumeration, "Invalid iterator");
         }
     }
 
@@ -178,10 +178,10 @@ public class ElementNodeTest extends AbstractPathTestSupport {
 
         final AbstractNode elementNode = parentNode.getChildren().get(0);
         try (AxisIterator iterator = elementNode.iterateAxis(AxisInfo.FOLLOWING_SIBLING)) {
-            assertTrue("Invalid iterator", iterator instanceof EmptyIterator);
+            assertTrue(iterator instanceof EmptyIterator, "Invalid iterator");
         }
         try (AxisIterator iterator = elementNode.iterateAxis(AxisInfo.PRECEDING_SIBLING)) {
-            assertTrue("Invalid iterator", iterator instanceof EmptyIterator);
+            assertTrue(iterator instanceof EmptyIterator, "Invalid iterator");
         }
     }
 }
