@@ -985,4 +985,78 @@ class New {
         final int c = a + 1;
     }
 
+    void test() {
+        int a = 0;
+
+        System.lineSeparator();
+        System.lineSeparator();
+        System.lineSeparator();
+        for (int i = 0; i < 10; i++) {
+            if (true) {
+                System.identityHashCode(a);
+            }
+            else {
+                System.identityHashCode(a);
+            }
+        }
+
+        int b = 0;
+        try {
+            for (int i = 0; i < 10; i++) {
+                if (true) {
+                    System.lineSeparator();
+                    System.lineSeparator();
+                    System.lineSeparator();
+                    b = i;
+                }
+            }
+
+            System.lineSeparator();
+            System.lineSeparator();
+        }
+        catch (Exception e) {
+            System.lineSeparator();
+        }
+        finally {
+            System.identityHashCode(b);
+        }
+
+        int c = 0;
+        System.lineSeparator();
+        System.lineSeparator();
+        System.lineSeparator();
+
+        if (false) {
+
+        }
+        else if (c == 1) {
+            if (c != 2) {
+                System.lineSeparator();
+            }
+
+            System.identityHashCode(c);
+        }
+        else if (c == 2) {
+            System.identityHashCode(c);
+        }
+    }
+
+    private void launch(Integer number ) {
+        String myInt = ( number.toString() + '\0' );
+        boolean result = false;
+        if (number == 123)
+            result = true;
+    }
+
+    static int field;
+
+    private void n() {
+        long a = 0;
+
+        New.field = 1;
+        New.field = 2;
+        New.field = 3;
+        New.field = (int)a;
+    }
+
 }
