@@ -36,7 +36,7 @@ public class InputMutableException {
                 if(true) {
                     final int i = 0;
                 }
-            } 
+            }
         }
     }
 
@@ -45,4 +45,12 @@ public class InputMutableException {
     class CustomMutableException extends java.lang.Exception {
         int errorCode;
     }
+
+    class ExampleException extends java.lang.Exception {
+        public void test() {
+            Throwable cause = super.getCause();
+            if (!(cause instanceof java.io.IOException))
+                throw new IllegalStateException("Test");
+        }
+    }
 }
